"""Contains all the data models used in inputs/outputs"""

from .award_model import AwardModel
from .award_model_award import AwardModelAward
from .award_model_competition import AwardModelCompetition
from .award_model_competition_resource_type import AwardModelCompetitionResourceType
from .award_model_entity import AwardModelEntity
from .award_model_entity_group import AwardModelEntityGroup
from .award_model_entity_group_resource_type import AwardModelEntityGroupResourceType
from .award_model_entity_resource_type import AwardModelEntityResourceType
from .award_model_fixture import AwardModelFixture
from .award_model_fixture_resource_type import AwardModelFixtureResourceType
from .award_model_organization import AwardModelOrganization
from .award_model_organization_resource_type import AwardModelOrganizationResourceType
from .award_model_person import AwardModelPerson
from .award_model_person_resource_type import AwardModelPersonResourceType
from .award_model_season import AwardModelSeason
from .award_model_season_resource_type import AwardModelSeasonResourceType
from .awards_detail_awards_response import AwardsDetailAwardsResponse
from .awards_detail_response_default import AwardsDetailResponseDefault
from .awards_list_fixtures_award import AwardsListFixturesAward
from .awards_list_fixtures_awards_response import AwardsListFixturesAwardsResponse
from .awards_list_fixtures_response_default import AwardsListFixturesResponseDefault
from .awards_list_non_fixtures_award import AwardsListNonFixturesAward
from .awards_list_non_fixtures_awards_response import AwardsListNonFixturesAwardsResponse
from .awards_list_non_fixtures_response_default import AwardsListNonFixturesResponseDefault
from .awards_list_seasons_award import AwardsListSeasonsAward
from .awards_list_seasons_awards_response import AwardsListSeasonsAwardsResponse
from .awards_list_seasons_response_default import AwardsListSeasonsResponseDefault
from .blank_model_model import BlankModelModel
from .caprs_list_age_group import CaprsListAgeGroup
from .caprs_list_career_person_representational_statistics_response import (
    CaprsListCareerPersonRepresentationalStatisticsResponse,
)
from .caprs_list_discipline import CaprsListDiscipline
from .caprs_list_fixture_type import CaprsListFixtureType
from .caprs_list_home_away import CaprsListHomeAway
from .caprs_list_representation import CaprsListRepresentation
from .caprs_list_representing_country import CaprsListRepresentingCountry
from .caprs_list_response_default import CaprsListResponseDefault
from .caprs_list_win_loss import CaprsListWinLoss
from .caps_list_career_person_statistics_response import CapsListCareerPersonStatisticsResponse
from .caps_list_fixture_type import CapsListFixtureType
from .caps_list_home_away import CapsListHomeAway
from .caps_list_person_season_career_person_season_statistics_response import (
    CapsListPersonSeasonCareerPersonSeasonStatisticsResponse,
)
from .caps_list_person_season_fixture_type import CapsListPersonSeasonFixtureType
from .caps_list_person_season_home_away import CapsListPersonSeasonHomeAway
from .caps_list_person_season_response_default import CapsListPersonSeasonResponseDefault
from .caps_list_person_season_win_loss import CapsListPersonSeasonWinLoss
from .caps_list_response_default import CapsListResponseDefault
from .caps_list_win_loss import CapsListWinLoss
from .caps_listperson_career_person_statistics_response import CapsListpersonCareerPersonStatisticsResponse
from .caps_listperson_fixture_type import CapsListpersonFixtureType
from .caps_listperson_home_away import CapsListpersonHomeAway
from .caps_listperson_response_default import CapsListpersonResponseDefault
from .caps_listperson_win_loss import CapsListpersonWinLoss
from .career_person_representational_statistics_model import CareerPersonRepresentationalStatisticsModel
from .career_person_representational_statistics_model_age_group import (
    CareerPersonRepresentationalStatisticsModelAgeGroup,
)
from .career_person_representational_statistics_model_discipline_type_1 import (
    CareerPersonRepresentationalStatisticsModelDisciplineType1,
)
from .career_person_representational_statistics_model_discipline_type_2_type_1 import (
    CareerPersonRepresentationalStatisticsModelDisciplineType2Type1,
)
from .career_person_representational_statistics_model_discipline_type_3_type_1 import (
    CareerPersonRepresentationalStatisticsModelDisciplineType3Type1,
)
from .career_person_representational_statistics_model_organization import (
    CareerPersonRepresentationalStatisticsModelOrganization,
)
from .career_person_representational_statistics_model_organization_resource_type import (
    CareerPersonRepresentationalStatisticsModelOrganizationResourceType,
)
from .career_person_representational_statistics_model_person import CareerPersonRepresentationalStatisticsModelPerson
from .career_person_representational_statistics_model_person_resource_type import (
    CareerPersonRepresentationalStatisticsModelPersonResourceType,
)
from .career_person_representational_statistics_model_statistics import (
    CareerPersonRepresentationalStatisticsModelStatistics,
)
from .career_person_season_statistics_model import CareerPersonSeasonStatisticsModel
from .career_person_season_statistics_model_entity import CareerPersonSeasonStatisticsModelEntity
from .career_person_season_statistics_model_entity_resource_type import (
    CareerPersonSeasonStatisticsModelEntityResourceType,
)
from .career_person_season_statistics_model_organization import CareerPersonSeasonStatisticsModelOrganization
from .career_person_season_statistics_model_organization_resource_type import (
    CareerPersonSeasonStatisticsModelOrganizationResourceType,
)
from .career_person_season_statistics_model_person import CareerPersonSeasonStatisticsModelPerson
from .career_person_season_statistics_model_person_resource_type import (
    CareerPersonSeasonStatisticsModelPersonResourceType,
)
from .career_person_season_statistics_model_season import CareerPersonSeasonStatisticsModelSeason
from .career_person_season_statistics_model_season_resource_type import (
    CareerPersonSeasonStatisticsModelSeasonResourceType,
)
from .career_person_season_statistics_model_statistics import CareerPersonSeasonStatisticsModelStatistics
from .career_person_statistics_model import CareerPersonStatisticsModel
from .career_person_statistics_model_organization import CareerPersonStatisticsModelOrganization
from .career_person_statistics_model_organization_resource_type import (
    CareerPersonStatisticsModelOrganizationResourceType,
)
from .career_person_statistics_model_person import CareerPersonStatisticsModelPerson
from .career_person_statistics_model_person_resource_type import CareerPersonStatisticsModelPersonResourceType
from .career_person_statistics_model_statistics import CareerPersonStatisticsModelStatistics
from .ces_list_competition_entity_statistics_response import CesListCompetitionEntityStatisticsResponse
from .ces_list_fixture_type import CesListFixtureType
from .ces_list_home_away import CesListHomeAway
from .ces_list_response_default import CesListResponseDefault
from .ces_list_win_loss import CesListWinLoss
from .ces_listentity_competition_entity_statistics_response import CesListentityCompetitionEntityStatisticsResponse
from .ces_listentity_fixture_type import CesListentityFixtureType
from .ces_listentity_home_away import CesListentityHomeAway
from .ces_listentity_periods_competition_entity_statistics_response import (
    CesListentityPeriodsCompetitionEntityStatisticsResponse,
)
from .ces_listentity_periods_fixture_type import CesListentityPeriodsFixtureType
from .ces_listentity_periods_home_away import CesListentityPeriodsHomeAway
from .ces_listentity_periods_period_id import CesListentityPeriodsPeriodId
from .ces_listentity_periods_response_default import CesListentityPeriodsResponseDefault
from .ces_listentity_periods_win_loss import CesListentityPeriodsWinLoss
from .ces_listentity_response_default import CesListentityResponseDefault
from .ces_listentity_win_loss import CesListentityWinLoss
from .ces_listperiods_competition_entity_statistics_response import CesListperiodsCompetitionEntityStatisticsResponse
from .ces_listperiods_fixture_type import CesListperiodsFixtureType
from .ces_listperiods_home_away import CesListperiodsHomeAway
from .ces_listperiods_period_id import CesListperiodsPeriodId
from .ces_listperiods_response_default import CesListperiodsResponseDefault
from .ces_listperiods_win_loss import CesListperiodsWinLoss
from .change_log_list_change_log_response import ChangeLogListChangeLogResponse
from .change_log_list_change_type import ChangeLogListChangeType
from .change_log_list_response_default import ChangeLogListResponseDefault
from .change_log_model import ChangeLogModel
from .change_log_model_change_type import ChangeLogModelChangeType
from .change_log_model_organization import ChangeLogModelOrganization
from .change_log_model_organization_resource_type import ChangeLogModelOrganizationResourceType
from .club_external_ids_model import ClubExternalIdsModel
from .club_external_ids_model_entity_group import ClubExternalIdsModelEntityGroup
from .club_external_ids_model_entity_group_resource_type import ClubExternalIdsModelEntityGroupResourceType
from .club_external_ids_model_organization import ClubExternalIdsModelOrganization
from .club_external_ids_model_organization_resource_type import ClubExternalIdsModelOrganizationResourceType
from .club_model import ClubModel
from .club_model_additional_names import ClubModelAdditionalNames
from .club_model_club_address import ClubModelClubAddress
from .club_model_club_historical_name import ClubModelClubHistoricalName
from .club_model_colors import ClubModelColors
from .club_model_contact_details import ClubModelContactDetails
from .club_model_entity_additional_details import ClubModelEntityAdditionalDetails
from .club_model_organization import ClubModelOrganization
from .club_model_organization_resource_type import ClubModelOrganizationResourceType
from .club_model_social_media import ClubModelSocialMedia
from .club_model_status import ClubModelStatus
from .competition_detail_competitions_response import CompetitionDetailCompetitionsResponse
from .competition_detail_response_default import CompetitionDetailResponseDefault
from .competition_entity_statistics_model import CompetitionEntityStatisticsModel
from .competition_entity_statistics_model_competition import CompetitionEntityStatisticsModelCompetition
from .competition_entity_statistics_model_competition_resource_type import (
    CompetitionEntityStatisticsModelCompetitionResourceType,
)
from .competition_entity_statistics_model_entity import CompetitionEntityStatisticsModelEntity
from .competition_entity_statistics_model_entity_resource_type import CompetitionEntityStatisticsModelEntityResourceType
from .competition_entity_statistics_model_organization import CompetitionEntityStatisticsModelOrganization
from .competition_entity_statistics_model_organization_resource_type import (
    CompetitionEntityStatisticsModelOrganizationResourceType,
)
from .competition_entity_statistics_model_statistics import CompetitionEntityStatisticsModelStatistics
from .competition_external_ids_detail_competition_external_ids_response import (
    CompetitionExternalIdsDetailCompetitionExternalIdsResponse,
)
from .competition_external_ids_detail_response_default import CompetitionExternalIdsDetailResponseDefault
from .competition_external_ids_list_competition_external_ids_response import (
    CompetitionExternalIdsListCompetitionExternalIdsResponse,
)
from .competition_external_ids_list_response_default import CompetitionExternalIdsListResponseDefault
from .competition_external_ids_model import CompetitionExternalIdsModel
from .competition_external_ids_model_competition import CompetitionExternalIdsModelCompetition
from .competition_external_ids_model_competition_resource_type import CompetitionExternalIdsModelCompetitionResourceType
from .competition_external_ids_model_organization import CompetitionExternalIdsModelOrganization
from .competition_external_ids_model_organization_resource_type import (
    CompetitionExternalIdsModelOrganizationResourceType,
)
from .competition_list_age_group import CompetitionListAgeGroup
from .competition_list_by_league_id_age_group import CompetitionListByLeagueIdAgeGroup
from .competition_list_by_league_id_competitions_response import CompetitionListByLeagueIdCompetitionsResponse
from .competition_list_by_league_id_response_default import CompetitionListByLeagueIdResponseDefault
from .competition_list_competitions_response import CompetitionListCompetitionsResponse
from .competition_list_response_default import CompetitionListResponseDefault
from .competition_list_season_status_age_group import CompetitionListSeasonStatusAgeGroup
from .competition_list_season_status_competitions_season_status_response import (
    CompetitionListSeasonStatusCompetitionsSeasonStatusResponse,
)
from .competition_list_season_status_response_default import CompetitionListSeasonStatusResponseDefault
from .competition_list_season_status_season_status import CompetitionListSeasonStatusSeasonStatus
from .competition_list_season_status_season_video_production import CompetitionListSeasonStatusSeasonVideoProduction
from .competition_model import CompetitionModel
from .competition_model_age_group_type_1 import CompetitionModelAgeGroupType1
from .competition_model_age_group_type_2_type_1 import CompetitionModelAgeGroupType2Type1
from .competition_model_age_group_type_3_type_1 import CompetitionModelAgeGroupType3Type1
from .competition_model_competition_historical_name import CompetitionModelCompetitionHistoricalName
from .competition_model_event_type import CompetitionModelEventType
from .competition_model_league import CompetitionModelLeague
from .competition_model_league_resource_type import CompetitionModelLeagueResourceType
from .competition_model_organization import CompetitionModelOrganization
from .competition_model_organization_resource_type import CompetitionModelOrganizationResourceType
from .competition_model_social_media import CompetitionModelSocialMedia
from .competition_person_statistics_model import CompetitionPersonStatisticsModel
from .competition_person_statistics_model_competition import CompetitionPersonStatisticsModelCompetition
from .competition_person_statistics_model_competition_resource_type import (
    CompetitionPersonStatisticsModelCompetitionResourceType,
)
from .competition_person_statistics_model_organization import CompetitionPersonStatisticsModelOrganization
from .competition_person_statistics_model_organization_resource_type import (
    CompetitionPersonStatisticsModelOrganizationResourceType,
)
from .competition_person_statistics_model_person import CompetitionPersonStatisticsModelPerson
from .competition_person_statistics_model_person_resource_type import CompetitionPersonStatisticsModelPersonResourceType
from .competition_person_statistics_model_statistics import CompetitionPersonStatisticsModelStatistics
from .competition_season_status_model import CompetitionSeasonStatusModel
from .competition_season_status_model_age_group_type_1 import CompetitionSeasonStatusModelAgeGroupType1
from .competition_season_status_model_age_group_type_2_type_1 import CompetitionSeasonStatusModelAgeGroupType2Type1
from .competition_season_status_model_age_group_type_3_type_1 import CompetitionSeasonStatusModelAgeGroupType3Type1
from .competition_season_status_model_competition_historical_name import (
    CompetitionSeasonStatusModelCompetitionHistoricalName,
)
from .competition_season_status_model_event_type import CompetitionSeasonStatusModelEventType
from .competition_season_status_model_league import CompetitionSeasonStatusModelLeague
from .competition_season_status_model_league_resource_type import CompetitionSeasonStatusModelLeagueResourceType
from .competition_season_status_model_organization import CompetitionSeasonStatusModelOrganization
from .competition_season_status_model_organization_resource_type import (
    CompetitionSeasonStatusModelOrganizationResourceType,
)
from .competition_season_status_model_social_media import CompetitionSeasonStatusModelSocialMedia
from .conduct_detail_conduct_response import ConductDetailConductResponse
from .conduct_detail_response_default import ConductDetailResponseDefault
from .conduct_list_conduct_response import ConductListConductResponse
from .conduct_list_conduct_status_type_1 import ConductListConductStatusType1
from .conduct_list_conduct_status_type_2_type_1 import ConductListConductStatusType2Type1
from .conduct_list_conduct_status_type_3_type_1 import ConductListConductStatusType3Type1
from .conduct_list_conduct_type import ConductListConductType
from .conduct_list_response_default import ConductListResponseDefault
from .conduct_model import ConductModel
from .conduct_model_competition import ConductModelCompetition
from .conduct_model_competition_resource_type import ConductModelCompetitionResourceType
from .conduct_model_conduct_penalty_result import ConductModelConductPenaltyResult
from .conduct_model_conduct_penalty_result_penalty_type import ConductModelConductPenaltyResultPenaltyType
from .conduct_model_conduct_type_item import ConductModelConductTypeItem
from .conduct_model_entity import ConductModelEntity
from .conduct_model_entity_group import ConductModelEntityGroup
from .conduct_model_entity_group_resource_type import ConductModelEntityGroupResourceType
from .conduct_model_entity_resource_type import ConductModelEntityResourceType
from .conduct_model_fine_status_type_1 import ConductModelFineStatusType1
from .conduct_model_fine_status_type_2_type_1 import ConductModelFineStatusType2Type1
from .conduct_model_fine_status_type_3_type_1 import ConductModelFineStatusType3Type1
from .conduct_model_fixture import ConductModelFixture
from .conduct_model_fixture_resource_type import ConductModelFixtureResourceType
from .conduct_model_hearing_status_type_1 import ConductModelHearingStatusType1
from .conduct_model_hearing_status_type_2_type_1 import ConductModelHearingStatusType2Type1
from .conduct_model_hearing_status_type_3_type_1 import ConductModelHearingStatusType3Type1
from .conduct_model_organization import ConductModelOrganization
from .conduct_model_organization_resource_type import ConductModelOrganizationResourceType
from .conduct_model_period_id import ConductModelPeriodId
from .conduct_model_person import ConductModelPerson
from .conduct_model_person_resource_type import ConductModelPersonResourceType
from .conduct_model_role_type_1 import ConductModelRoleType1
from .conduct_model_role_type_2_type_1 import ConductModelRoleType2Type1
from .conduct_model_role_type_3_type_1 import ConductModelRoleType3Type1
from .conduct_model_season import ConductModelSeason
from .conduct_model_season_resource_type import ConductModelSeasonResourceType
from .conduct_model_status_type_1 import ConductModelStatusType1
from .conduct_model_status_type_2_type_1 import ConductModelStatusType2Type1
from .conduct_model_status_type_3_type_1 import ConductModelStatusType3Type1
from .conduct_model_venue import ConductModelVenue
from .conduct_model_venue_resource_type import ConductModelVenueResourceType
from .conference_detail_conferences_response import ConferenceDetailConferencesResponse
from .conference_detail_response_default import ConferenceDetailResponseDefault
from .conference_external_ids_detail_conference_external_ids_response import (
    ConferenceExternalIdsDetailConferenceExternalIdsResponse,
)
from .conference_external_ids_detail_response_default import ConferenceExternalIdsDetailResponseDefault
from .conference_external_ids_list_conference_external_ids_response import (
    ConferenceExternalIdsListConferenceExternalIdsResponse,
)
from .conference_external_ids_list_response_default import ConferenceExternalIdsListResponseDefault
from .conference_external_ids_model import ConferenceExternalIdsModel
from .conference_external_ids_model_conference import ConferenceExternalIdsModelConference
from .conference_external_ids_model_conference_resource_type import ConferenceExternalIdsModelConferenceResourceType
from .conference_external_ids_model_organization import ConferenceExternalIdsModelOrganization
from .conference_external_ids_model_organization_resource_type import ConferenceExternalIdsModelOrganizationResourceType
from .conference_list_conferences_response import ConferenceListConferencesResponse
from .conference_list_response_default import ConferenceListResponseDefault
from .conference_model import ConferenceModel
from .conference_model_organization import ConferenceModelOrganization
from .conference_model_organization_resource_type import ConferenceModelOrganizationResourceType
from .conference_model_social_media import ConferenceModelSocialMedia
from .cps_list_competition_person_statistics_response import CpsListCompetitionPersonStatisticsResponse
from .cps_list_fixture_type import CpsListFixtureType
from .cps_list_home_away import CpsListHomeAway
from .cps_list_response_default import CpsListResponseDefault
from .cps_list_win_loss import CpsListWinLoss
from .division_detail_divisions_response import DivisionDetailDivisionsResponse
from .division_detail_response_default import DivisionDetailResponseDefault
from .division_external_ids_detail_division_external_ids_response import (
    DivisionExternalIdsDetailDivisionExternalIdsResponse,
)
from .division_external_ids_detail_response_default import DivisionExternalIdsDetailResponseDefault
from .division_external_ids_list_division_external_ids_response import (
    DivisionExternalIdsListDivisionExternalIdsResponse,
)
from .division_external_ids_list_response_default import DivisionExternalIdsListResponseDefault
from .division_external_ids_model import DivisionExternalIdsModel
from .division_external_ids_model_division import DivisionExternalIdsModelDivision
from .division_external_ids_model_division_resource_type import DivisionExternalIdsModelDivisionResourceType
from .division_external_ids_model_organization import DivisionExternalIdsModelOrganization
from .division_external_ids_model_organization_resource_type import DivisionExternalIdsModelOrganizationResourceType
from .division_list_divisions_response import DivisionListDivisionsResponse
from .division_list_response_default import DivisionListResponseDefault
from .division_model import DivisionModel
from .division_model_conference import DivisionModelConference
from .division_model_conference_resource_type import DivisionModelConferenceResourceType
from .division_model_organization import DivisionModelOrganization
from .division_model_organization_resource_type import DivisionModelOrganizationResourceType
from .division_model_social_media import DivisionModelSocialMedia
from .entity_detail_entities_response import EntityDetailEntitiesResponse
from .entity_detail_response_default import EntityDetailResponseDefault
from .entity_external_ids_detail_entity_external_ids_response import EntityExternalIdsDetailEntityExternalIdsResponse
from .entity_external_ids_detail_response_default import EntityExternalIdsDetailResponseDefault
from .entity_external_ids_list_entity_external_ids_response import EntityExternalIdsListEntityExternalIdsResponse
from .entity_external_ids_list_response_default import EntityExternalIdsListResponseDefault
from .entity_group_detail_entity_groups_response import EntityGroupDetailEntityGroupsResponse
from .entity_group_detail_response_default import EntityGroupDetailResponseDefault
from .entity_group_external_ids_detail_entity_group_external_ids_response import (
    EntityGroupExternalIdsDetailEntityGroupExternalIdsResponse,
)
from .entity_group_external_ids_detail_response_default import EntityGroupExternalIdsDetailResponseDefault
from .entity_group_external_ids_list_entity_group_external_ids_response import (
    EntityGroupExternalIdsListEntityGroupExternalIdsResponse,
)
from .entity_group_external_ids_list_response_default import EntityGroupExternalIdsListResponseDefault
from .entity_group_list_entity_groups_response import EntityGroupListEntityGroupsResponse
from .entity_group_list_response_default import EntityGroupListResponseDefault
from .entity_group_list_status import EntityGroupListStatus
from .entity_list_age_group import EntityListAgeGroup
from .entity_list_by_entity_group_age_group import EntityListByEntityGroupAgeGroup
from .entity_list_by_entity_group_discipline import EntityListByEntityGroupDiscipline
from .entity_list_by_entity_group_entities_response import EntityListByEntityGroupEntitiesResponse
from .entity_list_by_entity_group_gender import EntityListByEntityGroupGender
from .entity_list_by_entity_group_response_default import EntityListByEntityGroupResponseDefault
from .entity_list_by_entity_group_standard import EntityListByEntityGroupStandard
from .entity_list_by_entity_group_status import EntityListByEntityGroupStatus
from .entity_list_discipline import EntityListDiscipline
from .entity_list_entities_response import EntityListEntitiesResponse
from .entity_list_gender import EntityListGender
from .entity_list_representing_country import EntityListRepresentingCountry
from .entity_list_response_default import EntityListResponseDefault
from .entity_list_standard import EntityListStandard
from .entity_list_status import EntityListStatus
from .error_list_model import ErrorListModel
from .error_list_model_reason import ErrorListModelReason
from .error_model import ErrorModel
from .fes_list_by_season_fixture_entity_statistics_response import FesListBySeasonFixtureEntityStatisticsResponse
from .fes_list_by_season_response_default import FesListBySeasonResponseDefault
from .fes_list_fixture_entity_statistics_response import FesListFixtureEntityStatisticsResponse
from .fes_list_response_default import FesListResponseDefault
from .fes_listlive_fixture_entity_statistics_response import FesListliveFixtureEntityStatisticsResponse
from .fes_listlive_response_default import FesListliveResponseDefault
from .fes_listperiod_by_season_fixture_entity_statistics_periods_response import (
    FesListperiodBySeasonFixtureEntityStatisticsPeriodsResponse,
)
from .fes_listperiod_by_season_response_default import FesListperiodBySeasonResponseDefault
from .fes_listperiod_fixture_entity_statistics_periods_response import (
    FesListperiodFixtureEntityStatisticsPeriodsResponse,
)
from .fes_listperiod_period_id import FesListperiodPeriodId
from .fes_listperiod_response_default import FesListperiodResponseDefault
from .fes_listperiodlive_fixture_entity_statistics_periods_response import (
    FesListperiodliveFixtureEntityStatisticsPeriodsResponse,
)
from .fes_listperiodlive_period_id import FesListperiodlivePeriodId
from .fes_listperiodlive_response_default import FesListperiodliveResponseDefault
from .fixture_by_competition_list_competitor_type import FixtureByCompetitionListCompetitorType
from .fixture_by_competition_list_discipline import FixtureByCompetitionListDiscipline
from .fixture_by_competition_list_fixture_type import FixtureByCompetitionListFixtureType
from .fixture_by_competition_list_response_default import FixtureByCompetitionListResponseDefault
from .fixture_by_competition_list_status import FixtureByCompetitionListStatus
from .fixture_by_entity_all_seasons_list_competitor_type import FixtureByEntityAllSeasonsListCompetitorType
from .fixture_by_entity_all_seasons_list_fixture_type import FixtureByEntityAllSeasonsListFixtureType
from .fixture_by_entity_all_seasons_list_response_default import FixtureByEntityAllSeasonsListResponseDefault
from .fixture_by_entity_all_seasons_list_status import FixtureByEntityAllSeasonsListStatus
from .fixture_by_entity_list_competitor_type import FixtureByEntityListCompetitorType
from .fixture_by_entity_list_discipline import FixtureByEntityListDiscipline
from .fixture_by_entity_list_fixture_type import FixtureByEntityListFixtureType
from .fixture_by_entity_list_response_default import FixtureByEntityListResponseDefault
from .fixture_by_entity_list_status import FixtureByEntityListStatus
from .fixture_detail_fixtures_response import FixtureDetailFixturesResponse
from .fixture_detail_response_default import FixtureDetailResponseDefault
from .fixture_entities_detail_fixture_entities_response import FixtureEntitiesDetailFixtureEntitiesResponse
from .fixture_entities_detail_response_default import FixtureEntitiesDetailResponseDefault
from .fixture_entities_list_fixture_entities_response import FixtureEntitiesListFixtureEntitiesResponse
from .fixture_entities_list_response_default import FixtureEntitiesListResponseDefault
from .fixture_external_ids_detail_fixture_external_ids_response import (
    FixtureExternalIdsDetailFixtureExternalIdsResponse,
)
from .fixture_external_ids_detail_response_default import FixtureExternalIdsDetailResponseDefault
from .fixture_external_ids_list_fixture_external_ids_response import FixtureExternalIdsListFixtureExternalIdsResponse
from .fixture_external_ids_list_response_default import FixtureExternalIdsListResponseDefault
from .fixture_list_competitor_type import FixtureListCompetitorType
from .fixture_list_discipline import FixtureListDiscipline
from .fixture_list_fixture_type import FixtureListFixtureType
from .fixture_list_fixtures_response import FixtureListFixturesResponse
from .fixture_list_response_default import FixtureListResponseDefault
from .fixture_list_status import FixtureListStatus
from .fixture_list_status_not import FixtureListStatusNot
from .fixture_live_summary_model import FixtureLiveSummaryModel
from .fixture_live_summary_model_clock_information import FixtureLiveSummaryModelClockInformation
from .fixture_live_summary_model_information_per_entity import FixtureLiveSummaryModelInformationPerEntity
from .fixture_live_summary_model_status_information import FixtureLiveSummaryModelStatusInformation
from .fixture_pbp_event_model import FixturePBPEventModel
from .fixture_pbp_event_model_class import FixturePBPEventModelClass
from .fixture_pbp_event_model_current_scores import FixturePBPEventModelCurrentScores
from .fixture_pbp_event_model_entity import FixturePBPEventModelEntity
from .fixture_pbp_event_model_entity_resource_type import FixturePBPEventModelEntityResourceType
from .fixture_pbp_event_model_fixture import FixturePBPEventModelFixture
from .fixture_pbp_event_model_fixture_resource_type import FixturePBPEventModelFixtureResourceType
from .fixture_pbp_event_model_organization import FixturePBPEventModelOrganization
from .fixture_pbp_event_model_organization_resource_type import FixturePBPEventModelOrganizationResourceType
from .fixture_pbp_event_model_period_id import FixturePBPEventModelPeriodId
from .fixture_pbp_event_model_person import FixturePBPEventModelPerson
from .fixture_pbp_event_model_person_resource_type import FixturePBPEventModelPersonResourceType
from .fixture_pbp_export_period_id import FixturePbpExportPeriodId
from .fixture_pbp_export_response_default import FixturePbpExportResponseDefault
from .fixture_pbp_export_success_response import FixturePbpExportSuccessResponse
from .fixture_pbp_external_export_period_id import FixturePbpExternalExportPeriodId
from .fixture_pbp_external_export_response_default import FixturePbpExternalExportResponseDefault
from .fixture_pbp_external_export_success_response import FixturePbpExternalExportSuccessResponse
from .fixture_pbp_external_list_fixture_pbp_external_response import FixturePbpExternalListFixturePbpExternalResponse
from .fixture_pbp_external_list_live_fixture_pbp_external_response import (
    FixturePbpExternalListLiveFixturePbpExternalResponse,
)
from .fixture_pbp_external_list_live_period_id import FixturePbpExternalListLivePeriodId
from .fixture_pbp_external_list_live_response_default import FixturePbpExternalListLiveResponseDefault
from .fixture_pbp_external_list_period_id import FixturePbpExternalListPeriodId
from .fixture_pbp_external_list_response_default import FixturePbpExternalListResponseDefault
from .fixture_pbp_external_model import FixturePbpExternalModel
from .fixture_pbp_external_model_event_details import FixturePbpExternalModelEventDetails
from .fixture_pbp_external_model_fixture import FixturePbpExternalModelFixture
from .fixture_pbp_external_model_fixture_resource_type import FixturePbpExternalModelFixtureResourceType
from .fixture_pbp_external_model_organization import FixturePbpExternalModelOrganization
from .fixture_pbp_external_model_organization_resource_type import FixturePbpExternalModelOrganizationResourceType
from .fixture_pbp_external_model_period_id import FixturePbpExternalModelPeriodId
from .fixture_pbp_list_fixture_pbp_event_response import FixturePbpListFixturePbpEventResponse
from .fixture_pbp_list_live_fixture_pbp_event_response import FixturePbpListLiveFixturePbpEventResponse
from .fixture_pbp_list_live_period_id import FixturePbpListLivePeriodId
from .fixture_pbp_list_live_response_default import FixturePbpListLiveResponseDefault
from .fixture_pbp_list_period_id import FixturePbpListPeriodId
from .fixture_pbp_list_response_default import FixturePbpListResponseDefault
from .fixture_pbp_model import FixturePbpModel
from .fixture_pbp_model_event_details import FixturePbpModelEventDetails
from .fixture_pbp_model_fixture import FixturePbpModelFixture
from .fixture_pbp_model_fixture_resource_type import FixturePbpModelFixtureResourceType
from .fixture_pbp_model_organization import FixturePbpModelOrganization
from .fixture_pbp_model_organization_resource_type import FixturePbpModelOrganizationResourceType
from .fixture_pbp_model_period_id import FixturePbpModelPeriodId
from .fixture_persons_detail_fixture_persons_response import FixturePersonsDetailFixturePersonsResponse
from .fixture_persons_detail_response_default import FixturePersonsDetailResponseDefault
from .fixture_persons_list_fixture_persons_response import FixturePersonsListFixturePersonsResponse
from .fixture_persons_list_response_default import FixturePersonsListResponseDefault
from .fixture_profiles_detail_fixture_profiles_response import FixtureProfilesDetailFixtureProfilesResponse
from .fixture_profiles_detail_response_default import FixtureProfilesDetailResponseDefault
from .fixture_profiles_for_fixture_fixture_profiles_response import FixtureProfilesForFixtureFixtureProfilesResponse
from .fixture_profiles_for_fixture_response_default import FixtureProfilesForFixtureResponseDefault
from .fixture_profiles_list_fixture_profiles_response import FixtureProfilesListFixtureProfilesResponse
from .fixture_profiles_list_response_default import FixtureProfilesListResponseDefault
from .fixture_progression_model import FixtureProgressionModel
from .fixture_progression_model_fixture import FixtureProgressionModelFixture
from .fixture_progression_model_fixture_resource_type import FixtureProgressionModelFixtureResourceType
from .fixture_progression_model_organization import FixtureProgressionModelOrganization
from .fixture_progression_model_organization_resource_type import FixtureProgressionModelOrganizationResourceType
from .fixture_progression_model_season import FixtureProgressionModelSeason
from .fixture_progression_model_season_resource_type import FixtureProgressionModelSeasonResourceType
from .fixture_progressions_detail_fixture_progressions_response import (
    FixtureProgressionsDetailFixtureProgressionsResponse,
)
from .fixture_progressions_detail_response_default import FixtureProgressionsDetailResponseDefault
from .fixture_progressions_list_fixture_progressions_response import FixtureProgressionsListFixtureProgressionsResponse
from .fixture_progressions_list_response_default import FixtureProgressionsListResponseDefault
from .fixture_roster_detail_fixture_roster_response import FixtureRosterDetailFixtureRosterResponse
from .fixture_roster_detail_response_default import FixtureRosterDetailResponseDefault
from .fixture_roster_list_by_entity_fixture_roster_response import FixtureRosterListByEntityFixtureRosterResponse
from .fixture_roster_list_by_entity_response_default import FixtureRosterListByEntityResponseDefault
from .fixture_roster_list_fixture_roster_response import FixtureRosterListFixtureRosterResponse
from .fixture_roster_list_response_default import FixtureRosterListResponseDefault
from .fls_list_fixture_live_summary_response import FlsListFixtureLiveSummaryResponse
from .fls_list_response_default import FlsListResponseDefault
from .fps_list_by_season_fixture_person_statistics_response import FpsListBySeasonFixturePersonStatisticsResponse
from .fps_list_by_season_response_default import FpsListBySeasonResponseDefault
from .fps_list_fixture_person_statistics_response import FpsListFixturePersonStatisticsResponse
from .fps_list_response_default import FpsListResponseDefault
from .fps_listlive_fixture_person_statistics_response import FpsListliveFixturePersonStatisticsResponse
from .fps_listlive_response_default import FpsListliveResponseDefault
from .fpsp_list_by_season_fixture_person_statistics_periods_response import (
    FpspListBySeasonFixturePersonStatisticsPeriodsResponse,
)
from .fpsp_list_by_season_response_default import FpspListBySeasonResponseDefault
from .fpsp_listperiod_fixture_person_statistics_periods_response import (
    FpspListperiodFixturePersonStatisticsPeriodsResponse,
)
from .fpsp_listperiod_period_id import FpspListperiodPeriodId
from .fpsp_listperiod_response_default import FpspListperiodResponseDefault
from .fpsp_listperiodlive_fixture_person_statistics_periods_response import (
    FpspListperiodliveFixturePersonStatisticsPeriodsResponse,
)
from .fpsp_listperiodlive_period_id import FpspListperiodlivePeriodId
from .fpsp_listperiodlive_response_default import FpspListperiodliveResponseDefault
from .game_log_entity_model import GameLogEntityModel
from .game_log_entity_model_entity import GameLogEntityModelEntity
from .game_log_entity_model_entity_resource_type import GameLogEntityModelEntityResourceType
from .game_log_entity_model_fixture import GameLogEntityModelFixture
from .game_log_entity_model_fixture_resource_type import GameLogEntityModelFixtureResourceType
from .game_log_entity_model_organization import GameLogEntityModelOrganization
from .game_log_entity_model_organization_resource_type import GameLogEntityModelOrganizationResourceType
from .game_log_entity_model_period_id import GameLogEntityModelPeriodId
from .game_log_entity_model_statistics import GameLogEntityModelStatistics
from .game_log_person_model import GameLogPersonModel
from .game_log_person_model_entity import GameLogPersonModelEntity
from .game_log_person_model_entity_resource_type import GameLogPersonModelEntityResourceType
from .game_log_person_model_fixture import GameLogPersonModelFixture
from .game_log_person_model_fixture_resource_type import GameLogPersonModelFixtureResourceType
from .game_log_person_model_organization import GameLogPersonModelOrganization
from .game_log_person_model_organization_resource_type import GameLogPersonModelOrganizationResourceType
from .game_log_person_model_period_id import GameLogPersonModelPeriodId
from .game_log_person_model_person import GameLogPersonModelPerson
from .game_log_person_model_person_resource_type import GameLogPersonModelPersonResourceType
from .game_log_person_model_position_type_1 import GameLogPersonModelPositionType1
from .game_log_person_model_position_type_2_type_1 import GameLogPersonModelPositionType2Type1
from .game_log_person_model_position_type_3_type_1 import GameLogPersonModelPositionType3Type1
from .game_log_person_model_statistics import GameLogPersonModelStatistics
from .gamelog_listentity_fixture_type import GamelogListentityFixtureType
from .gamelog_listentity_game_log_entity_response import GamelogListentityGameLogEntityResponse
from .gamelog_listentity_home_away import GamelogListentityHomeAway
from .gamelog_listentity_response_default import GamelogListentityResponseDefault
from .gamelog_listentity_win_loss import GamelogListentityWinLoss
from .gamelog_listperson_fixture_type import GamelogListpersonFixtureType
from .gamelog_listperson_game_log_person_response import GamelogListpersonGameLogPersonResponse
from .gamelog_listperson_home_away import GamelogListpersonHomeAway
from .gamelog_listperson_response_default import GamelogListpersonResponseDefault
from .gamelog_listperson_win_loss import GamelogListpersonWinLoss
from .head_to_head_entity_model import HeadToHeadEntityModel
from .head_to_head_entity_model_competition import HeadToHeadEntityModelCompetition
from .head_to_head_entity_model_competition_resource_type import HeadToHeadEntityModelCompetitionResourceType
from .head_to_head_entity_model_fixture import HeadToHeadEntityModelFixture
from .head_to_head_entity_model_fixture_resource_type import HeadToHeadEntityModelFixtureResourceType
from .head_to_head_entity_model_organization import HeadToHeadEntityModelOrganization
from .head_to_head_entity_model_organization_resource_type import HeadToHeadEntityModelOrganizationResourceType
from .head_to_head_entity_model_season import HeadToHeadEntityModelSeason
from .head_to_head_entity_model_season_resource_type import HeadToHeadEntityModelSeasonResourceType
from .head_to_head_list_fixtures_fixture_type import HeadToHeadListFixturesFixtureType
from .head_to_head_list_fixtures_head_to_head_entity_response import HeadToHeadListFixturesHeadToHeadEntityResponse
from .head_to_head_list_fixtures_mulitple_competitions_fixture_type import (
    HeadToHeadListFixturesMulitpleCompetitionsFixtureType,
)
from .head_to_head_list_fixtures_mulitple_competitions_head_to_head_entity_response import (
    HeadToHeadListFixturesMulitpleCompetitionsHeadToHeadEntityResponse,
)
from .head_to_head_list_fixtures_mulitple_competitions_response_default import (
    HeadToHeadListFixturesMulitpleCompetitionsResponseDefault,
)
from .head_to_head_list_fixtures_mulitple_competitions_status import HeadToHeadListFixturesMulitpleCompetitionsStatus
from .head_to_head_list_fixtures_mulitple_competitions_status_not import (
    HeadToHeadListFixturesMulitpleCompetitionsStatusNot,
)
from .head_to_head_list_fixtures_response_default import HeadToHeadListFixturesResponseDefault
from .head_to_head_list_fixtures_status import HeadToHeadListFixturesStatus
from .head_to_head_list_fixtures_status_not import HeadToHeadListFixturesStatusNot
from .images_detail_images_response import ImagesDetailImagesResponse
from .images_detail_response_default import ImagesDetailResponseDefault
from .images_for_fixture_list_base_type import ImagesForFixtureListBaseType
from .images_for_fixture_list_image_type import ImagesForFixtureListImageType
from .images_for_fixture_list_images_response import ImagesForFixtureListImagesResponse
from .images_for_fixture_list_rating import ImagesForFixtureListRating
from .images_for_fixture_list_response_default import ImagesForFixtureListResponseDefault
from .images_list_base_type import ImagesListBaseType
from .images_list_id_base_type import ImagesListIdBaseType
from .images_list_id_image_type import ImagesListIdImageType
from .images_list_id_images_response import ImagesListIdImagesResponse
from .images_list_id_rating import ImagesListIdRating
from .images_list_id_response_default import ImagesListIdResponseDefault
from .images_list_id_secondary_base_type import ImagesListIdSecondaryBaseType
from .images_list_id_secondary_image_type import ImagesListIdSecondaryImageType
from .images_list_id_secondary_images_response import ImagesListIdSecondaryImagesResponse
from .images_list_id_secondary_rating import ImagesListIdSecondaryRating
from .images_list_id_secondary_response_default import ImagesListIdSecondaryResponseDefault
from .images_list_id_secondary_secondary_type import ImagesListIdSecondarySecondaryType
from .images_list_image_type import ImagesListImageType
from .images_list_images_response import ImagesListImagesResponse
from .images_list_organization_base_type import ImagesListOrganizationBaseType
from .images_list_organization_image_type import ImagesListOrganizationImageType
from .images_list_organization_images_response import ImagesListOrganizationImagesResponse
from .images_list_organization_rating import ImagesListOrganizationRating
from .images_list_organization_response_default import ImagesListOrganizationResponseDefault
from .images_list_rating import ImagesListRating
from .images_list_response_default import ImagesListResponseDefault
from .images_list_secondary_base_type import ImagesListSecondaryBaseType
from .images_list_secondary_image_type import ImagesListSecondaryImageType
from .images_list_secondary_images_response import ImagesListSecondaryImagesResponse
from .images_list_secondary_rating import ImagesListSecondaryRating
from .images_list_secondary_response_default import ImagesListSecondaryResponseDefault
from .images_list_secondary_secondary_type import ImagesListSecondarySecondaryType
from .images_model import ImagesModel
from .images_model_base_type import ImagesModelBaseType
from .images_model_file_type import ImagesModelFileType
from .images_model_image_type import ImagesModelImageType
from .images_model_organization import ImagesModelOrganization
from .images_model_organization_resource_type import ImagesModelOrganizationResourceType
from .images_model_rating import ImagesModelRating
from .images_model_secondary_type_type_1 import ImagesModelSecondaryTypeType1
from .images_model_secondary_type_type_2_type_1 import ImagesModelSecondaryTypeType2Type1
from .images_model_secondary_type_type_3_type_1 import ImagesModelSecondaryTypeType3Type1
from .included_data import IncludedData
from .included_data_resources import IncludedDataResources
from .included_data_resources_additional_property import IncludedDataResourcesAdditionalProperty
from .leader_criteria_detail_leader_criteria_response import LeaderCriteriaDetailLeaderCriteriaResponse
from .leader_criteria_detail_response_default import LeaderCriteriaDetailResponseDefault
from .leader_criteria_list_leader_criteria_response import LeaderCriteriaListLeaderCriteriaResponse
from .leader_criteria_list_response_default import LeaderCriteriaListResponseDefault
from .leader_criteria_model import LeaderCriteriaModel
from .leader_criteria_model_organization import LeaderCriteriaModelOrganization
from .leader_criteria_model_organization_resource_type import LeaderCriteriaModelOrganizationResourceType
from .leader_qualifier_model import LeaderQualifierModel
from .leader_qualifier_model_comparison_type import LeaderQualifierModelComparisonType
from .leader_qualifier_model_leaders_criteria import LeaderQualifierModelLeadersCriteria
from .leader_qualifier_model_leaders_criteria_resource_type import LeaderQualifierModelLeadersCriteriaResourceType
from .leader_qualifier_model_organization import LeaderQualifierModelOrganization
from .leader_qualifier_model_organization_resource_type import LeaderQualifierModelOrganizationResourceType
from .leader_qualifiers_detail_leader_qualifiers_response import LeaderQualifiersDetailLeaderQualifiersResponse
from .leader_qualifiers_detail_response_default import LeaderQualifiersDetailResponseDefault
from .leader_qualifiers_list_leader_qualifiers_response import LeaderQualifiersListLeaderQualifiersResponse
from .leader_qualifiers_list_response_default import LeaderQualifiersListResponseDefault
from .league_detail_leagues_response import LeagueDetailLeaguesResponse
from .league_detail_response_default import LeagueDetailResponseDefault
from .league_external_ids_detail_league_external_ids_response import LeagueExternalIdsDetailLeagueExternalIdsResponse
from .league_external_ids_detail_response_default import LeagueExternalIdsDetailResponseDefault
from .league_external_ids_list_league_external_ids_response import LeagueExternalIdsListLeagueExternalIdsResponse
from .league_external_ids_list_response_default import LeagueExternalIdsListResponseDefault
from .league_external_ids_model import LeagueExternalIdsModel
from .league_external_ids_model_league import LeagueExternalIdsModelLeague
from .league_external_ids_model_league_resource_type import LeagueExternalIdsModelLeagueResourceType
from .league_external_ids_model_organization import LeagueExternalIdsModelOrganization
from .league_external_ids_model_organization_resource_type import LeagueExternalIdsModelOrganizationResourceType
from .league_list_leagues_response import LeagueListLeaguesResponse
from .league_list_region_type import LeagueListRegionType
from .league_list_response_default import LeagueListResponseDefault
from .league_model import LeagueModel
from .league_model_organization import LeagueModelOrganization
from .league_model_organization_resource_type import LeagueModelOrganizationResourceType
from .league_model_region_type import LeagueModelRegionType
from .league_model_social_media import LeagueModelSocialMedia
from .match_external_ids_model import MatchExternalIdsModel
from .match_external_ids_model_fixture import MatchExternalIdsModelFixture
from .match_external_ids_model_fixture_resource_type import MatchExternalIdsModelFixtureResourceType
from .match_external_ids_model_organization import MatchExternalIdsModelOrganization
from .match_external_ids_model_organization_resource_type import MatchExternalIdsModelOrganizationResourceType
from .match_model import MatchModel
from .match_model_broadcasts import MatchModelBroadcasts
from .match_model_broadcasts_broadcast_type import MatchModelBroadcastsBroadcastType
from .match_model_competitor_type import MatchModelCompetitorType
from .match_model_discipline_type_1 import MatchModelDisciplineType1
from .match_model_discipline_type_2_type_1 import MatchModelDisciplineType2Type1
from .match_model_discipline_type_3_type_1 import MatchModelDisciplineType3Type1
from .match_model_environmental_details import MatchModelEnvironmentalDetails
from .match_model_fixture_profile import MatchModelFixtureProfile
from .match_model_fixture_profile_resource_type import MatchModelFixtureProfileResourceType
from .match_model_fixture_type import MatchModelFixtureType
from .match_model_match_competitor import MatchModelMatchCompetitor
from .match_model_match_competitor_result_status import MatchModelMatchCompetitorResultStatus
from .match_model_match_competitor_roster_status import MatchModelMatchCompetitorRosterStatus
from .match_model_maximum_period_type_used_type_1 import MatchModelMaximumPeriodTypeUsedType1
from .match_model_maximum_period_type_used_type_2_type_1 import MatchModelMaximumPeriodTypeUsedType2Type1
from .match_model_maximum_period_type_used_type_3_type_1 import MatchModelMaximumPeriodTypeUsedType3Type1
from .match_model_organization import MatchModelOrganization
from .match_model_organization_resource_type import MatchModelOrganizationResourceType
from .match_model_pool import MatchModelPool
from .match_model_pool_resource_type import MatchModelPoolResourceType
from .match_model_practice_drill_type_type_1 import MatchModelPracticeDrillTypeType1
from .match_model_practice_drill_type_type_2_type_1 import MatchModelPracticeDrillTypeType2Type1
from .match_model_practice_drill_type_type_3_type_1 import MatchModelPracticeDrillTypeType3Type1
from .match_model_round import MatchModelRound
from .match_model_round_resource_type import MatchModelRoundResourceType
from .match_model_season import MatchModelSeason
from .match_model_season_resource_type import MatchModelSeasonResourceType
from .match_model_series import MatchModelSeries
from .match_model_series_resource_type import MatchModelSeriesResourceType
from .match_model_social_media import MatchModelSocialMedia
from .match_model_stage import MatchModelStage
from .match_model_stage_resource_type import MatchModelStageResourceType
from .match_model_status import MatchModelStatus
from .match_model_venue import MatchModelVenue
from .match_model_venue_resource_type import MatchModelVenueResourceType
from .match_person_statistics_model import MatchPersonStatisticsModel
from .match_person_statistics_model_entity import MatchPersonStatisticsModelEntity
from .match_person_statistics_model_entity_resource_type import MatchPersonStatisticsModelEntityResourceType
from .match_person_statistics_model_fixture import MatchPersonStatisticsModelFixture
from .match_person_statistics_model_fixture_resource_type import MatchPersonStatisticsModelFixtureResourceType
from .match_person_statistics_model_organization import MatchPersonStatisticsModelOrganization
from .match_person_statistics_model_organization_resource_type import MatchPersonStatisticsModelOrganizationResourceType
from .match_person_statistics_model_person import MatchPersonStatisticsModelPerson
from .match_person_statistics_model_person_resource_type import MatchPersonStatisticsModelPersonResourceType
from .match_person_statistics_model_position_type_1 import MatchPersonStatisticsModelPositionType1
from .match_person_statistics_model_position_type_2_type_1 import MatchPersonStatisticsModelPositionType2Type1
from .match_person_statistics_model_position_type_3_type_1 import MatchPersonStatisticsModelPositionType3Type1
from .match_person_statistics_model_statistics import MatchPersonStatisticsModelStatistics
from .match_person_statistics_periods_model import MatchPersonStatisticsPeriodsModel
from .match_person_statistics_periods_model_entity import MatchPersonStatisticsPeriodsModelEntity
from .match_person_statistics_periods_model_entity_resource_type import (
    MatchPersonStatisticsPeriodsModelEntityResourceType,
)
from .match_person_statistics_periods_model_fixture import MatchPersonStatisticsPeriodsModelFixture
from .match_person_statistics_periods_model_fixture_resource_type import (
    MatchPersonStatisticsPeriodsModelFixtureResourceType,
)
from .match_person_statistics_periods_model_organization import MatchPersonStatisticsPeriodsModelOrganization
from .match_person_statistics_periods_model_organization_resource_type import (
    MatchPersonStatisticsPeriodsModelOrganizationResourceType,
)
from .match_person_statistics_periods_model_period_id import MatchPersonStatisticsPeriodsModelPeriodId
from .match_person_statistics_periods_model_person import MatchPersonStatisticsPeriodsModelPerson
from .match_person_statistics_periods_model_person_resource_type import (
    MatchPersonStatisticsPeriodsModelPersonResourceType,
)
from .match_person_statistics_periods_model_statistics import MatchPersonStatisticsPeriodsModelStatistics
from .match_persons_model import MatchPersonsModel
from .match_persons_model_entity_group import MatchPersonsModelEntityGroup
from .match_persons_model_entity_group_resource_type import MatchPersonsModelEntityGroupResourceType
from .match_persons_model_fixture import MatchPersonsModelFixture
from .match_persons_model_fixture_resource_type import MatchPersonsModelFixtureResourceType
from .match_persons_model_organization import MatchPersonsModelOrganization
from .match_persons_model_organization_resource_type import MatchPersonsModelOrganizationResourceType
from .match_persons_model_person import MatchPersonsModelPerson
from .match_persons_model_person_resource_type import MatchPersonsModelPersonResourceType
from .match_persons_model_result_status import MatchPersonsModelResultStatus
from .match_persons_model_uniform import MatchPersonsModelUniform
from .match_persons_model_uniform_resource_type import MatchPersonsModelUniformResourceType
from .match_profiles_model import MatchProfilesModel
from .match_profiles_model_match_profile_configuration import MatchProfilesModelMatchProfileConfiguration
from .match_profiles_model_match_profile_configuration_match_roles_item import (
    MatchProfilesModelMatchProfileConfigurationMatchRolesItem,
)
from .match_profiles_model_match_profile_configuration_type_of_cards_item import (
    MatchProfilesModelMatchProfileConfigurationTypeOfCardsItem,
)
from .match_profiles_model_organization import MatchProfilesModelOrganization
from .match_profiles_model_organization_resource_type import MatchProfilesModelOrganizationResourceType
from .match_roster_model import MatchRosterModel
from .match_roster_model_entity import MatchRosterModelEntity
from .match_roster_model_entity_resource_type import MatchRosterModelEntityResourceType
from .match_roster_model_fixture import MatchRosterModelFixture
from .match_roster_model_fixture_resource_type import MatchRosterModelFixtureResourceType
from .match_roster_model_organization import MatchRosterModelOrganization
from .match_roster_model_organization_resource_type import MatchRosterModelOrganizationResourceType
from .match_roster_model_person import MatchRosterModelPerson
from .match_roster_model_person_resource_type import MatchRosterModelPersonResourceType
from .match_roster_model_position_type_1 import MatchRosterModelPositionType1
from .match_roster_model_position_type_2_type_1 import MatchRosterModelPositionType2Type1
from .match_roster_model_position_type_3_type_1 import MatchRosterModelPositionType3Type1
from .match_team_period_statistics_model import MatchTeamPeriodStatisticsModel
from .match_team_period_statistics_model_entity import MatchTeamPeriodStatisticsModelEntity
from .match_team_period_statistics_model_entity_resource_type import MatchTeamPeriodStatisticsModelEntityResourceType
from .match_team_period_statistics_model_fixture import MatchTeamPeriodStatisticsModelFixture
from .match_team_period_statistics_model_fixture_resource_type import MatchTeamPeriodStatisticsModelFixtureResourceType
from .match_team_period_statistics_model_organization import MatchTeamPeriodStatisticsModelOrganization
from .match_team_period_statistics_model_organization_resource_type import (
    MatchTeamPeriodStatisticsModelOrganizationResourceType,
)
from .match_team_period_statistics_model_period_id import MatchTeamPeriodStatisticsModelPeriodId
from .match_team_period_statistics_model_statistics import MatchTeamPeriodStatisticsModelStatistics
from .match_team_statistics_model import MatchTeamStatisticsModel
from .match_team_statistics_model_entity import MatchTeamStatisticsModelEntity
from .match_team_statistics_model_entity_resource_type import MatchTeamStatisticsModelEntityResourceType
from .match_team_statistics_model_fixture import MatchTeamStatisticsModelFixture
from .match_team_statistics_model_fixture_resource_type import MatchTeamStatisticsModelFixtureResourceType
from .match_team_statistics_model_organization import MatchTeamStatisticsModelOrganization
from .match_team_statistics_model_organization_resource_type import MatchTeamStatisticsModelOrganizationResourceType
from .match_team_statistics_model_statistics import MatchTeamStatisticsModelStatistics
from .match_teams_model import MatchTeamsModel
from .match_teams_model_conference import MatchTeamsModelConference
from .match_teams_model_conference_resource_type import MatchTeamsModelConferenceResourceType
from .match_teams_model_division import MatchTeamsModelDivision
from .match_teams_model_division_resource_type import MatchTeamsModelDivisionResourceType
from .match_teams_model_entity import MatchTeamsModelEntity
from .match_teams_model_entity_resource_type import MatchTeamsModelEntityResourceType
from .match_teams_model_fixture import MatchTeamsModelFixture
from .match_teams_model_fixture_resource_type import MatchTeamsModelFixtureResourceType
from .match_teams_model_organization import MatchTeamsModelOrganization
from .match_teams_model_organization_resource_type import MatchTeamsModelOrganizationResourceType
from .match_teams_model_result_status import MatchTeamsModelResultStatus
from .match_teams_model_roster_status import MatchTeamsModelRosterStatus
from .match_teams_model_uniform import MatchTeamsModelUniform
from .match_teams_model_uniform_resource_type import MatchTeamsModelUniformResourceType
from .model import Model
from .organization_detail_organizations_response import OrganizationDetailOrganizationsResponse
from .organization_detail_response_default import OrganizationDetailResponseDefault
from .organization_fixture_list_competitor_type import OrganizationFixtureListCompetitorType
from .organization_fixture_list_discipline import OrganizationFixtureListDiscipline
from .organization_fixture_list_fixture_type import OrganizationFixtureListFixtureType
from .organization_fixture_list_fixtures_response import OrganizationFixtureListFixturesResponse
from .organization_fixture_list_response_default import OrganizationFixtureListResponseDefault
from .organization_fixture_list_status import OrganizationFixtureListStatus
from .organization_fixture_list_status_not import OrganizationFixtureListStatusNot
from .organization_list_organizations_response import OrganizationListOrganizationsResponse
from .organization_list_region_type import OrganizationListRegionType
from .organization_list_response_default import OrganizationListResponseDefault
from .organization_model import OrganizationModel
from .organization_model_region_type import OrganizationModelRegionType
from .orggroup_competition_list_competitions_response import OrggroupCompetitionListCompetitionsResponse
from .orggroup_competition_list_response_default import OrggroupCompetitionListResponseDefault
from .orggroup_fixture_detail_fixtures_response import OrggroupFixtureDetailFixturesResponse
from .orggroup_fixture_detail_response_default import OrggroupFixtureDetailResponseDefault
from .orggroup_fixture_list_competitor_type import OrggroupFixtureListCompetitorType
from .orggroup_fixture_list_fixture_type import OrggroupFixtureListFixtureType
from .orggroup_fixture_list_fixtures_response import OrggroupFixtureListFixturesResponse
from .orggroup_fixture_list_response_default import OrggroupFixtureListResponseDefault
from .orggroup_fixture_list_status import OrggroupFixtureListStatus
from .partners_get_blank_model_get_body import PartnersGetBlankModelGetBody
from .partners_get_blank_model_response import PartnersGetBlankModelResponse
from .partners_get_response_default import PartnersGetResponseDefault
from .person_detail_persons_response import PersonDetailPersonsResponse
from .person_detail_response_default import PersonDetailResponseDefault
from .person_external_ids_detail_person_external_ids_response import PersonExternalIdsDetailPersonExternalIdsResponse
from .person_external_ids_detail_response_default import PersonExternalIdsDetailResponseDefault
from .person_external_ids_list_person_external_ids_response import PersonExternalIdsListPersonExternalIdsResponse
from .person_external_ids_list_response_default import PersonExternalIdsListResponseDefault
from .person_external_ids_model import PersonExternalIdsModel
from .person_external_ids_model_organization import PersonExternalIdsModelOrganization
from .person_external_ids_model_organization_resource_type import PersonExternalIdsModelOrganizationResourceType
from .person_external_ids_model_person import PersonExternalIdsModelPerson
from .person_external_ids_model_person_resource_type import PersonExternalIdsModelPersonResourceType
from .person_list_gender import PersonListGender
from .person_list_persons_response import PersonListPersonsResponse
from .person_list_representing_country import PersonListRepresentingCountry
from .person_list_response_default import PersonListResponseDefault
from .person_list_status import PersonListStatus
from .person_model import PersonModel
from .person_model_additional_names_type_0 import PersonModelAdditionalNamesType0
from .person_model_additional_names_type_0_additional_property import PersonModelAdditionalNamesType0AdditionalProperty
from .person_model_gender import PersonModelGender
from .person_model_organization import PersonModelOrganization
from .person_model_organization_resource_type import PersonModelOrganizationResourceType
from .person_model_person_additional_details import PersonModelPersonAdditionalDetails
from .person_model_person_additional_details_dominant_foot import PersonModelPersonAdditionalDetailsDominantFoot
from .person_model_person_additional_details_dominant_hand import PersonModelPersonAdditionalDetailsDominantHand
from .person_model_person_historical_name import PersonModelPersonHistoricalName
from .person_model_social_media import PersonModelSocialMedia
from .person_model_status import PersonModelStatus
from .pool_model import PoolModel
from .pool_model_organization import PoolModelOrganization
from .pool_model_organization_resource_type import PoolModelOrganizationResourceType
from .pool_model_season import PoolModelSeason
from .pool_model_season_resource_type import PoolModelSeasonResourceType
from .pool_model_stage import PoolModelStage
from .pool_model_stage_resource_type import PoolModelStageResourceType
from .pss_list_age_group import PssListAgeGroup
from .pss_list_fixture_type import PssListFixtureType
from .pss_list_representation import PssListRepresentation
from .pss_list_response_default import PssListResponseDefault
from .pss_list_season_person_statistics_response import PssListSeasonPersonStatisticsResponse
from .pss_list_season_type import PssListSeasonType
from .pss_list_standard import PssListStandard
from .psts_list_age_group import PstsListAgeGroup
from .psts_list_fixture_type import PstsListFixtureType
from .psts_list_representation import PstsListRepresentation
from .psts_list_response_default import PstsListResponseDefault
from .psts_list_season_person_total_statistics_response import PstsListSeasonPersonTotalStatisticsResponse
from .psts_list_season_type import PstsListSeasonType
from .psts_list_standard import PstsListStandard
from .response_links import ResponseLinks
from .response_meta_data import ResponseMetaData
from .role_model import RoleModel
from .role_model_entity import RoleModelEntity
from .role_model_entity_group import RoleModelEntityGroup
from .role_model_entity_group_resource_type import RoleModelEntityGroupResourceType
from .role_model_entity_resource_type import RoleModelEntityResourceType
from .role_model_fixture import RoleModelFixture
from .role_model_fixture_resource_type import RoleModelFixtureResourceType
from .role_model_organization import RoleModelOrganization
from .role_model_organization_resource_type import RoleModelOrganizationResourceType
from .role_model_person import RoleModelPerson
from .role_model_person_resource_type import RoleModelPersonResourceType
from .role_model_role_type_1 import RoleModelRoleType1
from .role_model_season import RoleModelSeason
from .role_model_season_resource_type import RoleModelSeasonResourceType
from .role_model_status import RoleModelStatus
from .roles_detail_response_default import RolesDetailResponseDefault
from .roles_detail_roles_response import RolesDetailRolesResponse
from .roles_list_by_fixture_response_default import RolesListByFixtureResponseDefault
from .roles_list_by_fixture_role import RolesListByFixtureRole
from .roles_list_by_fixture_roles_response import RolesListByFixtureRolesResponse
from .roles_list_by_fixture_status import RolesListByFixtureStatus
from .roles_list_fixtures_response_default import RolesListFixturesResponseDefault
from .roles_list_fixtures_role import RolesListFixturesRole
from .roles_list_fixtures_roles_response import RolesListFixturesRolesResponse
from .roles_list_fixtures_status import RolesListFixturesStatus
from .roles_list_non_fixtures_response_default import RolesListNonFixturesResponseDefault
from .roles_list_non_fixtures_role import RolesListNonFixturesRole
from .roles_list_non_fixtures_roles_response import RolesListNonFixturesRolesResponse
from .roles_list_non_fixtures_status import RolesListNonFixturesStatus
from .round_model import RoundModel
from .round_model_organization import RoundModelOrganization
from .round_model_organization_resource_type import RoundModelOrganizationResourceType
from .round_model_pool import RoundModelPool
from .round_model_pool_resource_type import RoundModelPoolResourceType
from .round_model_season import RoundModelSeason
from .round_model_season_resource_type import RoundModelSeasonResourceType
from .round_model_stage import RoundModelStage
from .round_model_stage_resource_type import RoundModelStageResourceType
from .season_detail_response_default import SeasonDetailResponseDefault
from .season_detail_seasons_response import SeasonDetailSeasonsResponse
from .season_entities_detail_response_default import SeasonEntitiesDetailResponseDefault
from .season_entities_detail_season_entities_response import SeasonEntitiesDetailSeasonEntitiesResponse
from .season_entities_list_response_default import SeasonEntitiesListResponseDefault
from .season_entities_list_season_entities_list_response import SeasonEntitiesListSeasonEntitiesListResponse
from .season_entities_model import SeasonEntitiesModel
from .season_entities_model_conference import SeasonEntitiesModelConference
from .season_entities_model_conference_resource_type import SeasonEntitiesModelConferenceResourceType
from .season_entities_model_division import SeasonEntitiesModelDivision
from .season_entities_model_division_resource_type import SeasonEntitiesModelDivisionResourceType
from .season_entities_model_entity import SeasonEntitiesModelEntity
from .season_entities_model_entity_resource_type import SeasonEntitiesModelEntityResourceType
from .season_entities_model_organization import SeasonEntitiesModelOrganization
from .season_entities_model_organization_resource_type import SeasonEntitiesModelOrganizationResourceType
from .season_entities_model_roster_status import SeasonEntitiesModelRosterStatus
from .season_entities_model_season import SeasonEntitiesModelSeason
from .season_entities_model_season_resource_type import SeasonEntitiesModelSeasonResourceType
from .season_entities_model_status import SeasonEntitiesModelStatus
from .season_entity_list_by_multiple_seasons_response_default import SeasonEntityListByMultipleSeasonsResponseDefault
from .season_entity_list_by_multiple_seasons_season_entities_list_response import (
    SeasonEntityListByMultipleSeasonsSeasonEntitiesListResponse,
)
from .season_entity_list_response_default import SeasonEntityListResponseDefault
from .season_entity_list_season_entities_list_response import SeasonEntityListSeasonEntitiesListResponse
from .season_entity_statistics_model import SeasonEntityStatisticsModel
from .season_entity_statistics_model_competition import SeasonEntityStatisticsModelCompetition
from .season_entity_statistics_model_competition_resource_type import SeasonEntityStatisticsModelCompetitionResourceType
from .season_entity_statistics_model_entity import SeasonEntityStatisticsModelEntity
from .season_entity_statistics_model_entity_resource_type import SeasonEntityStatisticsModelEntityResourceType
from .season_entity_statistics_model_organization import SeasonEntityStatisticsModelOrganization
from .season_entity_statistics_model_organization_resource_type import (
    SeasonEntityStatisticsModelOrganizationResourceType,
)
from .season_entity_statistics_model_period_id import SeasonEntityStatisticsModelPeriodId
from .season_entity_statistics_model_season import SeasonEntityStatisticsModelSeason
from .season_entity_statistics_model_season_resource_type import SeasonEntityStatisticsModelSeasonResourceType
from .season_entity_statistics_model_statistics import SeasonEntityStatisticsModelStatistics
from .season_external_ids_detail_response_default import SeasonExternalIdsDetailResponseDefault
from .season_external_ids_detail_season_external_ids_response import SeasonExternalIdsDetailSeasonExternalIdsResponse
from .season_external_ids_list_response_default import SeasonExternalIdsListResponseDefault
from .season_external_ids_list_season_external_ids_response import SeasonExternalIdsListSeasonExternalIdsResponse
from .season_external_ids_model import SeasonExternalIdsModel
from .season_external_ids_model_organization import SeasonExternalIdsModelOrganization
from .season_external_ids_model_organization_resource_type import SeasonExternalIdsModelOrganizationResourceType
from .season_external_ids_model_season import SeasonExternalIdsModelSeason
from .season_external_ids_model_season_resource_type import SeasonExternalIdsModelSeasonResourceType
from .season_fixture_stages_pools_list_fixture_type import SeasonFixtureStagesPoolsListFixtureType
from .season_fixture_stages_pools_list_response_default import SeasonFixtureStagesPoolsListResponseDefault
from .season_fixture_stages_pools_list_season_fixture_stages_pools_list_response import (
    SeasonFixtureStagesPoolsListSeasonFixtureStagesPoolsListResponse,
)
from .season_fixture_stages_pools_model import SeasonFixtureStagesPoolsModel
from .season_fixture_stages_pools_model_fixture_type import SeasonFixtureStagesPoolsModelFixtureType
from .season_fixture_stages_pools_model_organization import SeasonFixtureStagesPoolsModelOrganization
from .season_fixture_stages_pools_model_organization_resource_type import (
    SeasonFixtureStagesPoolsModelOrganizationResourceType,
)
from .season_fixture_stages_pools_model_pool import SeasonFixtureStagesPoolsModelPool
from .season_fixture_stages_pools_model_pool_resource_type import SeasonFixtureStagesPoolsModelPoolResourceType
from .season_fixture_stages_pools_model_season import SeasonFixtureStagesPoolsModelSeason
from .season_fixture_stages_pools_model_season_resource_type import SeasonFixtureStagesPoolsModelSeasonResourceType
from .season_fixture_stages_pools_model_stage import SeasonFixtureStagesPoolsModelStage
from .season_fixture_stages_pools_model_stage_resource_type import SeasonFixtureStagesPoolsModelStageResourceType
from .season_leader_summary_model import SeasonLeaderSummaryModel
from .season_list_age_group import SeasonListAgeGroup
from .season_list_by_organization_age_group import SeasonListByOrganizationAgeGroup
from .season_list_by_organization_discipline import SeasonListByOrganizationDiscipline
from .season_list_by_organization_event_type import SeasonListByOrganizationEventType
from .season_list_by_organization_gender import SeasonListByOrganizationGender
from .season_list_by_organization_representation import SeasonListByOrganizationRepresentation
from .season_list_by_organization_response_default import SeasonListByOrganizationResponseDefault
from .season_list_by_organization_season_type import SeasonListByOrganizationSeasonType
from .season_list_by_organization_seasons_response import SeasonListByOrganizationSeasonsResponse
from .season_list_by_organization_standard import SeasonListByOrganizationStandard
from .season_list_by_organization_status import SeasonListByOrganizationStatus
from .season_list_by_organization_video_production import SeasonListByOrganizationVideoProduction
from .season_list_discipline import SeasonListDiscipline
from .season_list_event_type import SeasonListEventType
from .season_list_gender import SeasonListGender
from .season_list_representation import SeasonListRepresentation
from .season_list_response_default import SeasonListResponseDefault
from .season_list_season_type import SeasonListSeasonType
from .season_list_seasons_response import SeasonListSeasonsResponse
from .season_list_standard import SeasonListStandard
from .season_list_status import SeasonListStatus
from .season_list_video_production import SeasonListVideoProduction
from .season_model import SeasonModel
from .season_model_age_group import SeasonModelAgeGroup
from .season_model_competition import SeasonModelCompetition
from .season_model_competition_resource_type import SeasonModelCompetitionResourceType
from .season_model_discipline_type_1 import SeasonModelDisciplineType1
from .season_model_discipline_type_2_type_1 import SeasonModelDisciplineType2Type1
from .season_model_discipline_type_3_type_1 import SeasonModelDisciplineType3Type1
from .season_model_event_type import SeasonModelEventType
from .season_model_fixture_profile import SeasonModelFixtureProfile
from .season_model_fixture_profile_resource_type import SeasonModelFixtureProfileResourceType
from .season_model_gender import SeasonModelGender
from .season_model_leaders_criteria import SeasonModelLeadersCriteria
from .season_model_leaders_criteria_resource_type import SeasonModelLeadersCriteriaResourceType
from .season_model_organization import SeasonModelOrganization
from .season_model_organization_resource_type import SeasonModelOrganizationResourceType
from .season_model_promotion_relegation_rules_type_0_item import SeasonModelPromotionRelegationRulesType0Item
from .season_model_promotion_relegation_rules_type_0_item_rule_type import (
    SeasonModelPromotionRelegationRulesType0ItemRuleType,
)
from .season_model_representation import SeasonModelRepresentation
from .season_model_season_configuration import SeasonModelSeasonConfiguration
from .season_model_season_type import SeasonModelSeasonType
from .season_model_seasonroster_configuration import SeasonModelSEASONROSTERConfiguration
from .season_model_seasonroster_configuration_season_roster_status_allowed_item import (
    SeasonModelSEASONROSTERConfigurationSeasonRosterStatusAllowedItem,
)
from .season_model_social_media import SeasonModelSocialMedia
from .season_model_standard import SeasonModelStandard
from .season_model_standing_configuration import SeasonModelStandingConfiguration
from .season_model_standing_configuration_resource_type import SeasonModelStandingConfigurationResourceType
from .season_model_status import SeasonModelStatus
from .season_model_video_production import SeasonModelVideoProduction
from .season_person_base_statistics_model import SeasonPersonBaseStatisticsModel
from .season_person_base_statistics_model_competitor_type import SeasonPersonBaseStatisticsModelCompetitorType
from .season_person_base_statistics_model_entity import SeasonPersonBaseStatisticsModelEntity
from .season_person_base_statistics_model_entity_resource_type import SeasonPersonBaseStatisticsModelEntityResourceType
from .season_person_base_statistics_model_fixture_type import SeasonPersonBaseStatisticsModelFixtureType
from .season_person_base_statistics_model_organization import SeasonPersonBaseStatisticsModelOrganization
from .season_person_base_statistics_model_organization_resource_type import (
    SeasonPersonBaseStatisticsModelOrganizationResourceType,
)
from .season_person_base_statistics_model_person import SeasonPersonBaseStatisticsModelPerson
from .season_person_base_statistics_model_person_resource_type import SeasonPersonBaseStatisticsModelPersonResourceType
from .season_person_base_statistics_model_season import SeasonPersonBaseStatisticsModelSeason
from .season_person_base_statistics_model_season_resource_type import SeasonPersonBaseStatisticsModelSeasonResourceType
from .season_person_base_statistics_model_statistics import SeasonPersonBaseStatisticsModelStatistics
from .season_person_list_response_default import SeasonPersonListResponseDefault
from .season_person_list_season_persons_list_response import SeasonPersonListSeasonPersonsListResponse
from .season_person_statistics_model import SeasonPersonStatisticsModel
from .season_person_statistics_model_competition import SeasonPersonStatisticsModelCompetition
from .season_person_statistics_model_competition_resource_type import SeasonPersonStatisticsModelCompetitionResourceType
from .season_person_statistics_model_entity import SeasonPersonStatisticsModelEntity
from .season_person_statistics_model_entity_resource_type import SeasonPersonStatisticsModelEntityResourceType
from .season_person_statistics_model_organization import SeasonPersonStatisticsModelOrganization
from .season_person_statistics_model_organization_resource_type import (
    SeasonPersonStatisticsModelOrganizationResourceType,
)
from .season_person_statistics_model_person import SeasonPersonStatisticsModelPerson
from .season_person_statistics_model_person_resource_type import SeasonPersonStatisticsModelPersonResourceType
from .season_person_statistics_model_season import SeasonPersonStatisticsModelSeason
from .season_person_statistics_model_season_resource_type import SeasonPersonStatisticsModelSeasonResourceType
from .season_person_statistics_model_statistics import SeasonPersonStatisticsModelStatistics
from .season_person_total_statistics_model import SeasonPersonTotalStatisticsModel
from .season_person_total_statistics_model_competition import SeasonPersonTotalStatisticsModelCompetition
from .season_person_total_statistics_model_competition_resource_type import (
    SeasonPersonTotalStatisticsModelCompetitionResourceType,
)
from .season_person_total_statistics_model_organization import SeasonPersonTotalStatisticsModelOrganization
from .season_person_total_statistics_model_organization_resource_type import (
    SeasonPersonTotalStatisticsModelOrganizationResourceType,
)
from .season_person_total_statistics_model_person import SeasonPersonTotalStatisticsModelPerson
from .season_person_total_statistics_model_person_resource_type import (
    SeasonPersonTotalStatisticsModelPersonResourceType,
)
from .season_person_total_statistics_model_season import SeasonPersonTotalStatisticsModelSeason
from .season_person_total_statistics_model_season_resource_type import (
    SeasonPersonTotalStatisticsModelSeasonResourceType,
)
from .season_person_total_statistics_model_statistics import SeasonPersonTotalStatisticsModelStatistics
from .season_persons_detail_response_default import SeasonPersonsDetailResponseDefault
from .season_persons_list_response_default import SeasonPersonsListResponseDefault
from .season_persons_list_season_persons_list_response import SeasonPersonsListSeasonPersonsListResponse
from .season_persons_model import SeasonPersonsModel
from .season_persons_model_entity_group import SeasonPersonsModelEntityGroup
from .season_persons_model_entity_group_resource_type import SeasonPersonsModelEntityGroupResourceType
from .season_persons_model_organization import SeasonPersonsModelOrganization
from .season_persons_model_organization_resource_type import SeasonPersonsModelOrganizationResourceType
from .season_persons_model_person import SeasonPersonsModelPerson
from .season_persons_model_person_resource_type import SeasonPersonsModelPersonResourceType
from .season_persons_model_season import SeasonPersonsModelSeason
from .season_persons_model_season_resource_type import SeasonPersonsModelSeasonResourceType
from .season_persons_model_status import SeasonPersonsModelStatus
from .season_pool_detail_response_default import SeasonPoolDetailResponseDefault
from .season_pool_detail_season_pools_response import SeasonPoolDetailSeasonPoolsResponse
from .season_pool_list_response_default import SeasonPoolListResponseDefault
from .season_pool_list_season_pools_response import SeasonPoolListSeasonPoolsResponse
from .season_roster_detail_response_default import SeasonRosterDetailResponseDefault
from .season_roster_detail_season_roster_response import SeasonRosterDetailSeasonRosterResponse
from .season_roster_detail_status import SeasonRosterDetailStatus
from .season_roster_list_by_entity_response_default import SeasonRosterListByEntityResponseDefault
from .season_roster_list_by_entity_season_roster_response import SeasonRosterListByEntitySeasonRosterResponse
from .season_roster_list_by_entity_status import SeasonRosterListByEntityStatus
from .season_roster_list_response_default import SeasonRosterListResponseDefault
from .season_roster_list_season_roster_response import SeasonRosterListSeasonRosterResponse
from .season_roster_list_status import SeasonRosterListStatus
from .season_roster_model import SeasonRosterModel
from .season_roster_model_conference import SeasonRosterModelConference
from .season_roster_model_conference_resource_type import SeasonRosterModelConferenceResourceType
from .season_roster_model_division import SeasonRosterModelDivision
from .season_roster_model_division_resource_type import SeasonRosterModelDivisionResourceType
from .season_roster_model_entity import SeasonRosterModelEntity
from .season_roster_model_entity_group import SeasonRosterModelEntityGroup
from .season_roster_model_entity_group_resource_type import SeasonRosterModelEntityGroupResourceType
from .season_roster_model_entity_resource_type import SeasonRosterModelEntityResourceType
from .season_roster_model_organization import SeasonRosterModelOrganization
from .season_roster_model_organization_resource_type import SeasonRosterModelOrganizationResourceType
from .season_roster_model_person import SeasonRosterModelPerson
from .season_roster_model_person_resource_type import SeasonRosterModelPersonResourceType
from .season_roster_model_position_type_1 import SeasonRosterModelPositionType1
from .season_roster_model_position_type_2_type_1 import SeasonRosterModelPositionType2Type1
from .season_roster_model_position_type_3_type_1 import SeasonRosterModelPositionType3Type1
from .season_roster_model_season import SeasonRosterModelSeason
from .season_roster_model_season_resource_type import SeasonRosterModelSeasonResourceType
from .season_roster_model_status import SeasonRosterModelStatus
from .season_round_detail_response_default import SeasonRoundDetailResponseDefault
from .season_round_detail_season_rounds_response import SeasonRoundDetailSeasonRoundsResponse
from .season_round_list_response_default import SeasonRoundListResponseDefault
from .season_round_list_season_rounds_response import SeasonRoundListSeasonRoundsResponse
from .season_series_detail_response_default import SeasonSeriesDetailResponseDefault
from .season_series_detail_season_series_response import SeasonSeriesDetailSeasonSeriesResponse
from .season_series_list_response_default import SeasonSeriesListResponseDefault
from .season_series_list_season_series_response import SeasonSeriesListSeasonSeriesResponse
from .season_series_list_series_type import SeasonSeriesListSeriesType
from .season_stage_detail_response_default import SeasonStageDetailResponseDefault
from .season_stage_detail_season_stages_response import SeasonStageDetailSeasonStagesResponse
from .season_stage_list_response_default import SeasonStageListResponseDefault
from .season_stage_list_season_stages_response import SeasonStageListSeasonStagesResponse
from .season_stage_model import SeasonStageModel
from .season_stage_model_organization import SeasonStageModelOrganization
from .season_stage_model_organization_resource_type import SeasonStageModelOrganizationResourceType
from .season_stage_model_season import SeasonStageModelSeason
from .season_stage_model_season_resource_type import SeasonStageModelSeasonResourceType
from .season_standings_stages_pools_list_fixture_type import SeasonStandingsStagesPoolsListFixtureType
from .season_standings_stages_pools_list_response_default import SeasonStandingsStagesPoolsListResponseDefault
from .season_standings_stages_pools_list_season_standings_stages_pools_list_response import (
    SeasonStandingsStagesPoolsListSeasonStandingsStagesPoolsListResponse,
)
from .season_standings_stages_pools_model import SeasonStandingsStagesPoolsModel
from .season_standings_stages_pools_model_organization import SeasonStandingsStagesPoolsModelOrganization
from .season_standings_stages_pools_model_organization_resource_type import (
    SeasonStandingsStagesPoolsModelOrganizationResourceType,
)
from .season_standings_stages_pools_model_pool import SeasonStandingsStagesPoolsModelPool
from .season_standings_stages_pools_model_pool_resource_type import SeasonStandingsStagesPoolsModelPoolResourceType
from .season_standings_stages_pools_model_season import SeasonStandingsStagesPoolsModelSeason
from .season_standings_stages_pools_model_season_resource_type import SeasonStandingsStagesPoolsModelSeasonResourceType
from .season_standings_stages_pools_model_stage import SeasonStandingsStagesPoolsModelStage
from .season_standings_stages_pools_model_stage_resource_type import SeasonStandingsStagesPoolsModelStageResourceType
from .season_team_base_statistics_model import SeasonTeamBaseStatisticsModel
from .season_team_base_statistics_model_competitor_type import SeasonTeamBaseStatisticsModelCompetitorType
from .season_team_base_statistics_model_entity import SeasonTeamBaseStatisticsModelEntity
from .season_team_base_statistics_model_entity_resource_type import SeasonTeamBaseStatisticsModelEntityResourceType
from .season_team_base_statistics_model_fixture_type import SeasonTeamBaseStatisticsModelFixtureType
from .season_team_base_statistics_model_organization import SeasonTeamBaseStatisticsModelOrganization
from .season_team_base_statistics_model_organization_resource_type import (
    SeasonTeamBaseStatisticsModelOrganizationResourceType,
)
from .season_team_base_statistics_model_season import SeasonTeamBaseStatisticsModelSeason
from .season_team_base_statistics_model_season_resource_type import SeasonTeamBaseStatisticsModelSeasonResourceType
from .season_team_base_statistics_model_statistics import SeasonTeamBaseStatisticsModelStatistics
from .season_teams_model import SeasonTeamsModel
from .season_teams_model_conference import SeasonTeamsModelConference
from .season_teams_model_conference_resource_type import SeasonTeamsModelConferenceResourceType
from .season_teams_model_division import SeasonTeamsModelDivision
from .season_teams_model_division_resource_type import SeasonTeamsModelDivisionResourceType
from .season_teams_model_entity import SeasonTeamsModelEntity
from .season_teams_model_entity_resource_type import SeasonTeamsModelEntityResourceType
from .season_teams_model_organization import SeasonTeamsModelOrganization
from .season_teams_model_organization_resource_type import SeasonTeamsModelOrganizationResourceType
from .season_teams_model_roster_status import SeasonTeamsModelRosterStatus
from .season_teams_model_season import SeasonTeamsModelSeason
from .season_teams_model_season_resource_type import SeasonTeamsModelSeasonResourceType
from .season_teams_model_status import SeasonTeamsModelStatus
from .season_venues_list_response_default import SeasonVenuesListResponseDefault
from .season_venues_list_season_venues_list_response import SeasonVenuesListSeasonVenuesListResponse
from .season_venues_model import SeasonVenuesModel
from .season_venues_model_organization import SeasonVenuesModelOrganization
from .season_venues_model_organization_resource_type import SeasonVenuesModelOrganizationResourceType
from .season_venues_model_season import SeasonVenuesModelSeason
from .season_venues_model_season_resource_type import SeasonVenuesModelSeasonResourceType
from .season_venues_model_season_venues_address import SeasonVenuesModelSeasonVenuesAddress
from .season_venues_model_site import SeasonVenuesModelSite
from .season_venues_model_site_resource_type import SeasonVenuesModelSiteResourceType
from .season_venues_model_social_media import SeasonVenuesModelSocialMedia
from .seasonperson_placings_model import SEASONPERSONPlacingsModel
from .seasonperson_placings_model_organization import SEASONPERSONPlacingsModelOrganization
from .seasonperson_placings_model_organization_resource_type import SEASONPERSONPlacingsModelOrganizationResourceType
from .seasonperson_placings_model_person import SEASONPERSONPlacingsModelPerson
from .seasonperson_placings_model_person_resource_type import SEASONPERSONPlacingsModelPersonResourceType
from .seasonperson_placings_model_season import SEASONPERSONPlacingsModelSeason
from .seasonperson_placings_model_season_resource_type import SEASONPERSONPlacingsModelSeasonResourceType
from .seasons_roster_list_by_entity_response_default import SeasonsRosterListByEntityResponseDefault
from .seasons_roster_list_by_entity_season_roster_response import SeasonsRosterListByEntitySeasonRosterResponse
from .seasons_roster_list_by_entity_status import SeasonsRosterListByEntityStatus
from .seasonteam_placings_model import SEASONTEAMPlacingsModel
from .seasonteam_placings_model_entity import SEASONTEAMPlacingsModelEntity
from .seasonteam_placings_model_entity_resource_type import SEASONTEAMPlacingsModelEntityResourceType
from .seasonteam_placings_model_organization import SEASONTEAMPlacingsModelOrganization
from .seasonteam_placings_model_organization_resource_type import SEASONTEAMPlacingsModelOrganizationResourceType
from .seasonteam_placings_model_season import SEASONTEAMPlacingsModelSeason
from .seasonteam_placings_model_season_resource_type import SEASONTEAMPlacingsModelSeasonResourceType
from .sebs_list_competitor_type import SebsListCompetitorType
from .sebs_list_fixture_type import SebsListFixtureType
from .sebs_list_representing_country import SebsListRepresentingCountry
from .sebs_list_response_default import SebsListResponseDefault
from .sebs_list_season_entity_base_statistics_response import SebsListSeasonEntityBaseStatisticsResponse
from .sep_detail_response_default import SepDetailResponseDefault
from .sep_detail_season_entity_placings_response import SepDetailSeasonEntityPlacingsResponse
from .sep_list_response_default import SepListResponseDefault
from .sep_list_season_entity_placings_response import SepListSeasonEntityPlacingsResponse
from .series_model import SeriesModel
from .series_model_conference import SeriesModelConference
from .series_model_conference_resource_type import SeriesModelConferenceResourceType
from .series_model_division import SeriesModelDivision
from .series_model_division_resource_type import SeriesModelDivisionResourceType
from .series_model_organization import SeriesModelOrganization
from .series_model_organization_resource_type import SeriesModelOrganizationResourceType
from .series_model_pool import SeriesModelPool
from .series_model_pool_resource_type import SeriesModelPoolResourceType
from .series_model_season import SeriesModelSeason
from .series_model_season_resource_type import SeriesModelSeasonResourceType
from .series_model_season_series_competitor import SeriesModelSeasonSeriesCompetitor
from .series_model_season_series_competitor_series_result import SeriesModelSeasonSeriesCompetitorSeriesResult
from .series_model_series_type import SeriesModelSeriesType
from .series_model_stage import SeriesModelStage
from .series_model_stage_resource_type import SeriesModelStageResourceType
from .series_model_status import SeriesModelStatus
from .ses_list_fixture_type import SesListFixtureType
from .ses_list_home_away import SesListHomeAway
from .ses_list_response_default import SesListResponseDefault
from .ses_list_season_entity_statistics_response import SesListSeasonEntityStatisticsResponse
from .ses_list_win_loss import SesListWinLoss
from .ses_listperiods_fixture_type import SesListperiodsFixtureType
from .ses_listperiods_home_away import SesListperiodsHomeAway
from .ses_listperiods_period_id import SesListperiodsPeriodId
from .ses_listperiods_response_default import SesListperiodsResponseDefault
from .ses_listperiods_season_entity_statistics_response import SesListperiodsSeasonEntityStatisticsResponse
from .ses_listperiods_win_loss import SesListperiodsWinLoss
from .site_detail_response_default import SiteDetailResponseDefault
from .site_detail_sites_response import SiteDetailSitesResponse
from .site_external_ids_detail_response_default import SiteExternalIdsDetailResponseDefault
from .site_external_ids_detail_site_external_ids_response import SiteExternalIdsDetailSiteExternalIdsResponse
from .site_external_ids_list_response_default import SiteExternalIdsListResponseDefault
from .site_external_ids_list_site_external_ids_response import SiteExternalIdsListSiteExternalIdsResponse
from .site_external_ids_model import SiteExternalIdsModel
from .site_external_ids_model_organization import SiteExternalIdsModelOrganization
from .site_external_ids_model_organization_resource_type import SiteExternalIdsModelOrganizationResourceType
from .site_external_ids_model_site import SiteExternalIdsModelSite
from .site_external_ids_model_site_resource_type import SiteExternalIdsModelSiteResourceType
from .site_list_response_default import SiteListResponseDefault
from .site_list_sites_response import SiteListSitesResponse
from .site_model import SiteModel
from .site_model_organization import SiteModelOrganization
from .site_model_organization_resource_type import SiteModelOrganizationResourceType
from .site_model_site_address import SiteModelSiteAddress
from .site_model_social_media import SiteModelSocialMedia
from .sl_list_fixture_type import SlListFixtureType
from .sl_list_home_away import SlListHomeAway
from .sl_list_response_default import SlListResponseDefault
from .sl_list_season_person_statistics_response import SlListSeasonPersonStatisticsResponse
from .sl_list_summary_fixture_type import SlListSummaryFixtureType
from .sl_list_summary_home_away import SlListSummaryHomeAway
from .sl_list_summary_leader_summary_response import SlListSummaryLeaderSummaryResponse
from .sl_list_summary_response_default import SlListSummaryResponseDefault
from .sl_list_summary_win_loss import SlListSummaryWinLoss
from .sl_list_win_loss import SlListWinLoss
from .spbs_list_competitor_type import SpbsListCompetitorType
from .spbs_list_fixture_type import SpbsListFixtureType
from .spbs_list_representing_country import SpbsListRepresentingCountry
from .spbs_list_response_default import SpbsListResponseDefault
from .spbs_list_season_person_base_statistics_response import SpbsListSeasonPersonBaseStatisticsResponse
from .spp_detail_response_default import SppDetailResponseDefault
from .spp_detail_season_person_placings_response import SppDetailSeasonPersonPlacingsResponse
from .spp_list_response_default import SppListResponseDefault
from .spp_list_season_person_placings_response import SppListSeasonPersonPlacingsResponse
from .sps_list_fixture_type import SpsListFixtureType
from .sps_list_home_away import SpsListHomeAway
from .sps_list_response_default import SpsListResponseDefault
from .sps_list_season_person_statistics_response import SpsListSeasonPersonStatisticsResponse
from .sps_list_win_loss import SpsListWinLoss
from .spsp_listperiods_fixture_type import SpspListperiodsFixtureType
from .spsp_listperiods_home_away import SpspListperiodsHomeAway
from .spsp_listperiods_period_id import SpspListperiodsPeriodId
from .spsp_listperiods_response_default import SpspListperiodsResponseDefault
from .spsp_listperiods_win_loss import SpspListperiodsWinLoss
from .spts_list_fixture_type import SptsListFixtureType
from .spts_list_home_away import SptsListHomeAway
from .spts_list_response_default import SptsListResponseDefault
from .spts_list_season_person_total_statistics_response import SptsListSeasonPersonTotalStatisticsResponse
from .spts_list_win_loss import SptsListWinLoss
from .standing_adjustment_model import StandingAdjustmentModel
from .standing_adjustment_model_adjustment_field import StandingAdjustmentModelAdjustmentField
from .standing_adjustment_model_adjustment_group import StandingAdjustmentModelAdjustmentGroup
from .standing_adjustment_model_adjustment_type import StandingAdjustmentModelAdjustmentType
from .standing_adjustment_model_conference import StandingAdjustmentModelConference
from .standing_adjustment_model_conference_resource_type import StandingAdjustmentModelConferenceResourceType
from .standing_adjustment_model_division import StandingAdjustmentModelDivision
from .standing_adjustment_model_division_resource_type import StandingAdjustmentModelDivisionResourceType
from .standing_adjustment_model_entity import StandingAdjustmentModelEntity
from .standing_adjustment_model_entity_resource_type import StandingAdjustmentModelEntityResourceType
from .standing_adjustment_model_organization import StandingAdjustmentModelOrganization
from .standing_adjustment_model_organization_resource_type import StandingAdjustmentModelOrganizationResourceType
from .standing_adjustment_model_pool import StandingAdjustmentModelPool
from .standing_adjustment_model_pool_resource_type import StandingAdjustmentModelPoolResourceType
from .standing_adjustment_model_round import StandingAdjustmentModelRound
from .standing_adjustment_model_round_resource_type import StandingAdjustmentModelRoundResourceType
from .standing_adjustment_model_season import StandingAdjustmentModelSeason
from .standing_adjustment_model_season_resource_type import StandingAdjustmentModelSeasonResourceType
from .standing_adjustment_model_stage import StandingAdjustmentModelStage
from .standing_adjustment_model_stage_resource_type import StandingAdjustmentModelStageResourceType
from .standing_adjustments_detail_response_default import StandingAdjustmentsDetailResponseDefault
from .standing_adjustments_detail_standing_adjustments_response import (
    StandingAdjustmentsDetailStandingAdjustmentsResponse,
)
from .standing_adjustments_list_response_default import StandingAdjustmentsListResponseDefault
from .standing_adjustments_list_standing_adjustments_response import StandingAdjustmentsListStandingAdjustmentsResponse
from .standing_configurations_detail_response_default import StandingConfigurationsDetailResponseDefault
from .standing_configurations_detail_standing_configurations_response import (
    StandingConfigurationsDetailStandingConfigurationsResponse,
)
from .standing_configurations_list_response_default import StandingConfigurationsListResponseDefault
from .standing_configurations_list_standing_configurations_response import (
    StandingConfigurationsListStandingConfigurationsResponse,
)
from .standing_configurations_model import StandingConfigurationsModel
from .standing_configurations_model_organization import StandingConfigurationsModelOrganization
from .standing_configurations_model_organization_resource_type import (
    StandingConfigurationsModelOrganizationResourceType,
)
from .standing_configurations_model_standing_building import StandingConfigurationsModelStandingBuilding
from .standing_configurations_model_standing_building_build_type import (
    StandingConfigurationsModelStandingBuildingBuildType,
)
from .standing_configurations_model_standing_building_fixture_types_item import (
    StandingConfigurationsModelStandingBuildingFixtureTypesItem,
)
from .standing_configurations_model_standing_building_grouping import (
    StandingConfigurationsModelStandingBuildingGrouping,
)
from .standing_configurations_model_standing_configuration import StandingConfigurationsModelStandingConfiguration
from .standing_configurations_model_standing_configuration_head_to_head_identification import (
    StandingConfigurationsModelStandingConfigurationHeadToHeadIdentification,
)
from .standing_configurations_model_standing_configuration_head_to_head_identification_for_subsequent_checks import (
    StandingConfigurationsModelStandingConfigurationHeadToHeadIdentificationForSubsequentChecks,
)
from .standing_configurations_model_standing_configuration_head_to_head_resolution import (
    StandingConfigurationsModelStandingConfigurationHeadToHeadResolution,
)
from .standing_configurations_model_standing_configuration_head_to_head_resolution_for_extra_depth_h2_hs import (
    StandingConfigurationsModelStandingConfigurationHeadToHeadResolutionForExtraDepthH2Hs,
)
from .standing_configurations_model_standing_configuration_head_to_head_resolution_for_extra_depth_h2_hs_sort_direction import (
    StandingConfigurationsModelStandingConfigurationHeadToHeadResolutionForExtraDepthH2HsSortDirection,
)
from .standing_configurations_model_standing_configuration_head_to_head_resolution_sort_direction import (
    StandingConfigurationsModelStandingConfigurationHeadToHeadResolutionSortDirection,
)
from .standing_configurations_model_standing_configuration_sorting import (
    StandingConfigurationsModelStandingConfigurationSorting,
)
from .standing_configurations_model_standing_configuration_sorting_sort_direction import (
    StandingConfigurationsModelStandingConfigurationSortingSortDirection,
)
from .standing_configurations_model_standing_configuration_streak import (
    StandingConfigurationsModelStandingConfigurationStreak,
)
from .standing_detail_response_default import StandingDetailResponseDefault
from .standing_detail_standings_response import StandingDetailStandingsResponse
from .standing_list_fixture_type import StandingListFixtureType
from .standing_list_grouping_base import StandingListGroupingBase
from .standing_list_grouping_conference_division import StandingListGroupingConferenceDivision
from .standing_list_grouping_stage_pool import StandingListGroupingStagePool
from .standing_list_response_default import StandingListResponseDefault
from .standing_list_standings_response import StandingListStandingsResponse
from .standing_live_list_fixture_type import StandingLiveListFixtureType
from .standing_live_list_grouping_base import StandingLiveListGroupingBase
from .standing_live_list_grouping_conference_division import StandingLiveListGroupingConferenceDivision
from .standing_live_list_grouping_stage_pool import StandingLiveListGroupingStagePool
from .standing_live_list_response_default import StandingLiveListResponseDefault
from .standing_live_list_standings_response import StandingLiveListStandingsResponse
from .standing_model import StandingModel
from .standing_model_calculated import StandingModelCalculated
from .standing_model_calculated_additional_property import StandingModelCalculatedAdditionalProperty
from .standing_model_conference import StandingModelConference
from .standing_model_conference_resource_type import StandingModelConferenceResourceType
from .standing_model_division import StandingModelDivision
from .standing_model_division_resource_type import StandingModelDivisionResourceType
from .standing_model_entity import StandingModelEntity
from .standing_model_entity_resource_type import StandingModelEntityResourceType
from .standing_model_fixture_type import StandingModelFixtureType
from .standing_model_grouping_base import StandingModelGroupingBase
from .standing_model_grouping_conference_division import StandingModelGroupingConferenceDivision
from .standing_model_grouping_stage_pool import StandingModelGroupingStagePool
from .standing_model_organization import StandingModelOrganization
from .standing_model_organization_resource_type import StandingModelOrganizationResourceType
from .standing_model_points import StandingModelPoints
from .standing_model_points_additional_property import StandingModelPointsAdditionalProperty
from .standing_model_pool import StandingModelPool
from .standing_model_pool_resource_type import StandingModelPoolResourceType
from .standing_model_round import StandingModelRound
from .standing_model_round_resource_type import StandingModelRoundResourceType
from .standing_model_season import StandingModelSeason
from .standing_model_season_resource_type import StandingModelSeasonResourceType
from .standing_model_stage import StandingModelStage
from .standing_model_stage_resource_type import StandingModelStageResourceType
from .standing_model_standing_configuration import StandingModelStandingConfiguration
from .standing_model_standing_configuration_resource_type import StandingModelStandingConfigurationResourceType
from .standing_progressions_detail_response_default import StandingProgressionsDetailResponseDefault
from .standing_progressions_detail_standing_progressions_response import (
    StandingProgressionsDetailStandingProgressionsResponse,
)
from .standing_progressions_list_response_default import StandingProgressionsListResponseDefault
from .standing_progressions_list_standing_progressions_response import (
    StandingProgressionsListStandingProgressionsResponse,
)
from .standing_progressions_model import StandingProgressionsModel
from .standing_progressions_model_organization import StandingProgressionsModelOrganization
from .standing_progressions_model_organization_resource_type import StandingProgressionsModelOrganizationResourceType
from .standing_progressions_model_pool import StandingProgressionsModelPool
from .standing_progressions_model_pool_resource_type import StandingProgressionsModelPoolResourceType
from .standing_progressions_model_season import StandingProgressionsModelSeason
from .standing_progressions_model_season_resource_type import StandingProgressionsModelSeasonResourceType
from .standing_progressions_model_stage import StandingProgressionsModelStage
from .standing_progressions_model_stage_resource_type import StandingProgressionsModelStageResourceType
from .team_external_ids_model import TeamExternalIdsModel
from .team_external_ids_model_entity import TeamExternalIdsModelEntity
from .team_external_ids_model_entity_resource_type import TeamExternalIdsModelEntityResourceType
from .team_external_ids_model_organization import TeamExternalIdsModelOrganization
from .team_external_ids_model_organization_resource_type import TeamExternalIdsModelOrganizationResourceType
from .team_model import TeamModel
from .team_model_additional_names import TeamModelAdditionalNames
from .team_model_age_group_type_1 import TeamModelAgeGroupType1
from .team_model_age_group_type_2_type_1 import TeamModelAgeGroupType2Type1
from .team_model_age_group_type_3_type_1 import TeamModelAgeGroupType3Type1
from .team_model_colors import TeamModelColors
from .team_model_contact_details import TeamModelContactDetails
from .team_model_discipline_type_1 import TeamModelDisciplineType1
from .team_model_discipline_type_2_type_1 import TeamModelDisciplineType2Type1
from .team_model_discipline_type_3_type_1 import TeamModelDisciplineType3Type1
from .team_model_entity_additional_details import TeamModelEntityAdditionalDetails
from .team_model_entity_group import TeamModelEntityGroup
from .team_model_entity_group_resource_type import TeamModelEntityGroupResourceType
from .team_model_gender_type_1 import TeamModelGenderType1
from .team_model_gender_type_2_type_1 import TeamModelGenderType2Type1
from .team_model_gender_type_3_type_1 import TeamModelGenderType3Type1
from .team_model_organization import TeamModelOrganization
from .team_model_organization_resource_type import TeamModelOrganizationResourceType
from .team_model_social_media import TeamModelSocialMedia
from .team_model_standard_type_1 import TeamModelStandardType1
from .team_model_standard_type_2_type_1 import TeamModelStandardType2Type1
from .team_model_standard_type_3_type_1 import TeamModelStandardType3Type1
from .team_model_status import TeamModelStatus
from .team_model_team_address import TeamModelTeamAddress
from .team_model_team_historical_name import TeamModelTeamHistoricalName
from .transfer_detail_response_default import TransferDetailResponseDefault
from .transfer_detail_transfers_response import TransferDetailTransfersResponse
from .transfer_model import TransferModel
from .transfer_model_competition import TransferModelCompetition
from .transfer_model_competition_resource_type import TransferModelCompetitionResourceType
from .transfer_model_organization import TransferModelOrganization
from .transfer_model_organization_resource_type import TransferModelOrganizationResourceType
from .transfer_model_season import TransferModelSeason
from .transfer_model_season_resource_type import TransferModelSeasonResourceType
from .transfer_model_status_type_1 import TransferModelStatusType1
from .transfer_model_status_type_2_type_1 import TransferModelStatusType2Type1
from .transfer_model_status_type_3_type_1 import TransferModelStatusType3Type1
from .transfer_model_transfer_component import TransferModelTransferComponent
from .transfer_model_transfer_type import TransferModelTransferType
from .transfers_list_response_default import TransfersListResponseDefault
from .transfers_list_transfer_type import TransfersListTransferType
from .transfers_list_transfers_response import TransfersListTransfersResponse
from .uniform_items_by_season_list_item_type import UniformItemsBySeasonListItemType
from .uniform_items_by_season_list_response_default import UniformItemsBySeasonListResponseDefault
from .uniform_items_by_season_list_uniform_items_response import UniformItemsBySeasonListUniformItemsResponse
from .uniform_items_detail_response_default import UniformItemsDetailResponseDefault
from .uniform_items_detail_uniform_items_response import UniformItemsDetailUniformItemsResponse
from .uniform_items_list_item_type import UniformItemsListItemType
from .uniform_items_list_response_default import UniformItemsListResponseDefault
from .uniform_items_list_uniform_items_response import UniformItemsListUniformItemsResponse
from .uniform_items_model import UniformItemsModel
from .uniform_items_model_colors import UniformItemsModelColors
from .uniform_items_model_item_type import UniformItemsModelItemType
from .uniform_items_model_organization import UniformItemsModelOrganization
from .uniform_items_model_organization_resource_type import UniformItemsModelOrganizationResourceType
from .uniform_items_model_uniform import UniformItemsModelUniform
from .uniform_items_model_uniform_resource_type import UniformItemsModelUniformResourceType
from .uniforms_by_season_list_base_type import UniformsBySeasonListBaseType
from .uniforms_by_season_list_response_default import UniformsBySeasonListResponseDefault
from .uniforms_by_season_list_uniforms_response import UniformsBySeasonListUniformsResponse
from .uniforms_detail_response_default import UniformsDetailResponseDefault
from .uniforms_detail_uniforms_response import UniformsDetailUniformsResponse
from .uniforms_list_base_type import UniformsListBaseType
from .uniforms_list_response_default import UniformsListResponseDefault
from .uniforms_list_uniforms_response import UniformsListUniformsResponse
from .uniforms_model import UniformsModel
from .uniforms_model_base_type import UniformsModelBaseType
from .uniforms_model_organization import UniformsModelOrganization
from .uniforms_model_organization_resource_type import UniformsModelOrganizationResourceType
from .venue_detail_response_default import VenueDetailResponseDefault
from .venue_detail_venues_response import VenueDetailVenuesResponse
from .venue_external_ids_detail_response_default import VenueExternalIdsDetailResponseDefault
from .venue_external_ids_detail_venue_external_ids_response import VenueExternalIdsDetailVenueExternalIdsResponse
from .venue_external_ids_list_response_default import VenueExternalIdsListResponseDefault
from .venue_external_ids_list_venue_external_ids_response import VenueExternalIdsListVenueExternalIdsResponse
from .venue_external_ids_model import VenueExternalIdsModel
from .venue_external_ids_model_organization import VenueExternalIdsModelOrganization
from .venue_external_ids_model_organization_resource_type import VenueExternalIdsModelOrganizationResourceType
from .venue_external_ids_model_venue import VenueExternalIdsModelVenue
from .venue_external_ids_model_venue_resource_type import VenueExternalIdsModelVenueResourceType
from .venue_list_by_site_id_response_default import VenueListBySiteIdResponseDefault
from .venue_list_by_site_id_status import VenueListBySiteIdStatus
from .venue_list_by_site_id_venues_response import VenueListBySiteIdVenuesResponse
from .venue_list_response_default import VenueListResponseDefault
from .venue_list_status import VenueListStatus
from .venue_list_venues_response import VenueListVenuesResponse
from .venue_model import VenueModel
from .venue_model_organization import VenueModelOrganization
from .venue_model_organization_resource_type import VenueModelOrganizationResourceType
from .venue_model_site import VenueModelSite
from .venue_model_site_resource_type import VenueModelSiteResourceType
from .venue_model_social_media import VenueModelSocialMedia
from .venue_model_status import VenueModelStatus
from .venue_model_venue_address import VenueModelVenueAddress
from .venue_model_venue_historical_name import VenueModelVenueHistoricalName
from .video_file_detail_response_default import VideoFileDetailResponseDefault
from .video_file_list_content import VideoFileListContent
from .video_file_list_feed_type import VideoFileListFeedType
from .video_file_list_format import VideoFileListFormat
from .video_file_list_origin import VideoFileListOrigin
from .video_file_list_response_default import VideoFileListResponseDefault
from .video_file_list_status import VideoFileListStatus
from .video_file_list_storage_provider import VideoFileListStorageProvider
from .video_file_list_video_files_response import VideoFileListVideoFilesResponse
from .video_file_model import VideoFileModel
from .video_file_model_content import VideoFileModelContent
from .video_file_model_feed_type import VideoFileModelFeedType
from .video_file_model_fixture import VideoFileModelFixture
from .video_file_model_fixture_resource_type import VideoFileModelFixtureResourceType
from .video_file_model_format import VideoFileModelFormat
from .video_file_model_organization import VideoFileModelOrganization
from .video_file_model_organization_resource_type import VideoFileModelOrganizationResourceType
from .video_file_model_origin_type_1 import VideoFileModelOriginType1
from .video_file_model_origin_type_2_type_1 import VideoFileModelOriginType2Type1
from .video_file_model_origin_type_3_type_1 import VideoFileModelOriginType3Type1
from .video_file_model_resolution import VideoFileModelResolution
from .video_file_model_status_type_1 import VideoFileModelStatusType1
from .video_file_model_status_type_2_type_1 import VideoFileModelStatusType2Type1
from .video_file_model_status_type_3_type_1 import VideoFileModelStatusType3Type1
from .video_file_model_storage_provider_type_1 import VideoFileModelStorageProviderType1
from .video_file_model_storage_provider_type_2_type_1 import VideoFileModelStorageProviderType2Type1
from .video_file_model_storage_provider_type_3_type_1 import VideoFileModelStorageProviderType3Type1
from .video_stream_inputs_fixture_list_feed_type import VideoStreamInputsFixtureListFeedType
from .video_stream_inputs_fixture_list_response_default import VideoStreamInputsFixtureListResponseDefault
from .video_stream_inputs_fixture_list_video_stream_inputs_response import (
    VideoStreamInputsFixtureListVideoStreamInputsResponse,
)
from .video_stream_inputs_list_feed_type import VideoStreamInputsListFeedType
from .video_stream_inputs_list_response_default import VideoStreamInputsListResponseDefault
from .video_stream_inputs_list_video_stream_inputs_response import VideoStreamInputsListVideoStreamInputsResponse
from .video_stream_inputs_model import VideoStreamInputsModel
from .video_stream_inputs_model_audio_ambience_channel import VideoStreamInputsModelAudioAmbienceChannel
from .video_stream_inputs_model_audio_commentary_channel import VideoStreamInputsModelAudioCommentaryChannel
from .video_stream_inputs_model_competition import VideoStreamInputsModelCompetition
from .video_stream_inputs_model_competition_resource_type import VideoStreamInputsModelCompetitionResourceType
from .video_stream_inputs_model_feed_type import VideoStreamInputsModelFeedType
from .video_stream_inputs_model_fixture import VideoStreamInputsModelFixture
from .video_stream_inputs_model_fixture_resource_type import VideoStreamInputsModelFixtureResourceType
from .video_stream_inputs_model_input_resolution import VideoStreamInputsModelInputResolution
from .video_stream_inputs_model_organization import VideoStreamInputsModelOrganization
from .video_stream_inputs_model_organization_resource_type import VideoStreamInputsModelOrganizationResourceType
from .video_stream_inputs_model_venue import VideoStreamInputsModelVenue
from .video_stream_inputs_model_venue_resource_type import VideoStreamInputsModelVenueResourceType
from .video_stream_inputs_org_list_feed_type import VideoStreamInputsOrgListFeedType
from .video_stream_inputs_org_list_response_default import VideoStreamInputsOrgListResponseDefault
from .video_stream_inputs_org_list_video_stream_inputs_response import VideoStreamInputsOrgListVideoStreamInputsResponse
from .video_stream_local_detail_response_default import VideoStreamLocalDetailResponseDefault
from .video_stream_local_detail_video_stream_local_response import VideoStreamLocalDetailVideoStreamLocalResponse
from .video_stream_local_list_format import VideoStreamLocalListFormat
from .video_stream_local_list_response_default import VideoStreamLocalListResponseDefault
from .video_stream_local_list_video_stream_local_response import VideoStreamLocalListVideoStreamLocalResponse
from .video_stream_local_model import VideoStreamLocalModel
from .video_stream_local_model_fixture import VideoStreamLocalModelFixture
from .video_stream_local_model_fixture_resource_type import VideoStreamLocalModelFixtureResourceType
from .video_stream_local_model_format import VideoStreamLocalModelFormat
from .video_stream_local_model_organization import VideoStreamLocalModelOrganization
from .video_stream_local_model_organization_resource_type import VideoStreamLocalModelOrganizationResourceType
from .video_stream_outputs_fixture_list_content import VideoStreamOutputsFixtureListContent
from .video_stream_outputs_fixture_list_feed_type import VideoStreamOutputsFixtureListFeedType
from .video_stream_outputs_fixture_list_response_default import VideoStreamOutputsFixtureListResponseDefault
from .video_stream_outputs_fixture_list_video_stream_outputs_response import (
    VideoStreamOutputsFixtureListVideoStreamOutputsResponse,
)
from .video_stream_outputs_model import VideoStreamOutputsModel
from .video_stream_outputs_model_competition import VideoStreamOutputsModelCompetition
from .video_stream_outputs_model_competition_resource_type import VideoStreamOutputsModelCompetitionResourceType
from .video_stream_outputs_model_content import VideoStreamOutputsModelContent
from .video_stream_outputs_model_feed_type import VideoStreamOutputsModelFeedType
from .video_stream_outputs_model_fixture import VideoStreamOutputsModelFixture
from .video_stream_outputs_model_fixture_resource_type import VideoStreamOutputsModelFixtureResourceType
from .video_stream_outputs_model_input_resolution import VideoStreamOutputsModelInputResolution
from .video_stream_outputs_model_organization import VideoStreamOutputsModelOrganization
from .video_stream_outputs_model_organization_resource_type import VideoStreamOutputsModelOrganizationResourceType
from .video_stream_outputs_model_venue import VideoStreamOutputsModelVenue
from .video_stream_outputs_model_venue_resource_type import VideoStreamOutputsModelVenueResourceType
from .video_stream_outputs_org_list_content import VideoStreamOutputsOrgListContent
from .video_stream_outputs_org_list_feed_type import VideoStreamOutputsOrgListFeedType
from .video_stream_outputs_org_list_response_default import VideoStreamOutputsOrgListResponseDefault
from .video_stream_outputs_org_list_video_stream_outputs_response import (
    VideoStreamOutputsOrgListVideoStreamOutputsResponse,
)
from .video_stream_outputs_orggroup_list_content import VideoStreamOutputsOrggroupListContent
from .video_stream_outputs_orggroup_list_feed_type import VideoStreamOutputsOrggroupListFeedType
from .video_stream_outputs_orggroup_list_response_default import VideoStreamOutputsOrggroupListResponseDefault
from .video_stream_outputs_orggroup_list_video_stream_outputs_response import (
    VideoStreamOutputsOrggroupListVideoStreamOutputsResponse,
)
from .video_subscription_detail_response_default import VideoSubscriptionDetailResponseDefault
from .video_subscription_detail_video_subscriptions_response import VideoSubscriptionDetailVideoSubscriptionsResponse
from .video_subscription_list_response_default import VideoSubscriptionListResponseDefault
from .video_subscription_list_video_subscriptions_response import VideoSubscriptionListVideoSubscriptionsResponse
from .video_subscription_model import VideoSubscriptionModel
from .video_subscription_model_audio import VideoSubscriptionModelAudio
from .video_subscription_model_content import VideoSubscriptionModelContent
from .video_subscription_model_feed_type import VideoSubscriptionModelFeedType
from .video_subscription_model_fixture import VideoSubscriptionModelFixture
from .video_subscription_model_fixture_resource_type import VideoSubscriptionModelFixtureResourceType
from .video_subscription_model_organization import VideoSubscriptionModelOrganization
from .video_subscription_model_organization_resource_type import VideoSubscriptionModelOrganizationResourceType
from .video_subscription_model_output_format import VideoSubscriptionModelOutputFormat
from .video_subscription_model_output_resolution import VideoSubscriptionModelOutputResolution

__all__ = (
    "AwardModel",
    "AwardModelAward",
    "AwardModelCompetition",
    "AwardModelCompetitionResourceType",
    "AwardModelEntity",
    "AwardModelEntityGroup",
    "AwardModelEntityGroupResourceType",
    "AwardModelEntityResourceType",
    "AwardModelFixture",
    "AwardModelFixtureResourceType",
    "AwardModelOrganization",
    "AwardModelOrganizationResourceType",
    "AwardModelPerson",
    "AwardModelPersonResourceType",
    "AwardModelSeason",
    "AwardModelSeasonResourceType",
    "AwardsDetailAwardsResponse",
    "AwardsDetailResponseDefault",
    "AwardsListFixturesAward",
    "AwardsListFixturesAwardsResponse",
    "AwardsListFixturesResponseDefault",
    "AwardsListNonFixturesAward",
    "AwardsListNonFixturesAwardsResponse",
    "AwardsListNonFixturesResponseDefault",
    "AwardsListSeasonsAward",
    "AwardsListSeasonsAwardsResponse",
    "AwardsListSeasonsResponseDefault",
    "BlankModelModel",
    "CaprsListAgeGroup",
    "CaprsListCareerPersonRepresentationalStatisticsResponse",
    "CaprsListDiscipline",
    "CaprsListFixtureType",
    "CaprsListHomeAway",
    "CaprsListRepresentation",
    "CaprsListRepresentingCountry",
    "CaprsListResponseDefault",
    "CaprsListWinLoss",
    "CapsListCareerPersonStatisticsResponse",
    "CapsListFixtureType",
    "CapsListHomeAway",
    "CapsListpersonCareerPersonStatisticsResponse",
    "CapsListpersonFixtureType",
    "CapsListpersonHomeAway",
    "CapsListpersonResponseDefault",
    "CapsListPersonSeasonCareerPersonSeasonStatisticsResponse",
    "CapsListPersonSeasonFixtureType",
    "CapsListPersonSeasonHomeAway",
    "CapsListPersonSeasonResponseDefault",
    "CapsListPersonSeasonWinLoss",
    "CapsListpersonWinLoss",
    "CapsListResponseDefault",
    "CapsListWinLoss",
    "CareerPersonRepresentationalStatisticsModel",
    "CareerPersonRepresentationalStatisticsModelAgeGroup",
    "CareerPersonRepresentationalStatisticsModelDisciplineType1",
    "CareerPersonRepresentationalStatisticsModelDisciplineType2Type1",
    "CareerPersonRepresentationalStatisticsModelDisciplineType3Type1",
    "CareerPersonRepresentationalStatisticsModelOrganization",
    "CareerPersonRepresentationalStatisticsModelOrganizationResourceType",
    "CareerPersonRepresentationalStatisticsModelPerson",
    "CareerPersonRepresentationalStatisticsModelPersonResourceType",
    "CareerPersonRepresentationalStatisticsModelStatistics",
    "CareerPersonSeasonStatisticsModel",
    "CareerPersonSeasonStatisticsModelEntity",
    "CareerPersonSeasonStatisticsModelEntityResourceType",
    "CareerPersonSeasonStatisticsModelOrganization",
    "CareerPersonSeasonStatisticsModelOrganizationResourceType",
    "CareerPersonSeasonStatisticsModelPerson",
    "CareerPersonSeasonStatisticsModelPersonResourceType",
    "CareerPersonSeasonStatisticsModelSeason",
    "CareerPersonSeasonStatisticsModelSeasonResourceType",
    "CareerPersonSeasonStatisticsModelStatistics",
    "CareerPersonStatisticsModel",
    "CareerPersonStatisticsModelOrganization",
    "CareerPersonStatisticsModelOrganizationResourceType",
    "CareerPersonStatisticsModelPerson",
    "CareerPersonStatisticsModelPersonResourceType",
    "CareerPersonStatisticsModelStatistics",
    "CesListCompetitionEntityStatisticsResponse",
    "CesListentityCompetitionEntityStatisticsResponse",
    "CesListentityFixtureType",
    "CesListentityHomeAway",
    "CesListentityPeriodsCompetitionEntityStatisticsResponse",
    "CesListentityPeriodsFixtureType",
    "CesListentityPeriodsHomeAway",
    "CesListentityPeriodsPeriodId",
    "CesListentityPeriodsResponseDefault",
    "CesListentityPeriodsWinLoss",
    "CesListentityResponseDefault",
    "CesListentityWinLoss",
    "CesListFixtureType",
    "CesListHomeAway",
    "CesListperiodsCompetitionEntityStatisticsResponse",
    "CesListperiodsFixtureType",
    "CesListperiodsHomeAway",
    "CesListperiodsPeriodId",
    "CesListperiodsResponseDefault",
    "CesListperiodsWinLoss",
    "CesListResponseDefault",
    "CesListWinLoss",
    "ChangeLogListChangeLogResponse",
    "ChangeLogListChangeType",
    "ChangeLogListResponseDefault",
    "ChangeLogModel",
    "ChangeLogModelChangeType",
    "ChangeLogModelOrganization",
    "ChangeLogModelOrganizationResourceType",
    "ClubExternalIdsModel",
    "ClubExternalIdsModelEntityGroup",
    "ClubExternalIdsModelEntityGroupResourceType",
    "ClubExternalIdsModelOrganization",
    "ClubExternalIdsModelOrganizationResourceType",
    "ClubModel",
    "ClubModelAdditionalNames",
    "ClubModelClubAddress",
    "ClubModelClubHistoricalName",
    "ClubModelColors",
    "ClubModelContactDetails",
    "ClubModelEntityAdditionalDetails",
    "ClubModelOrganization",
    "ClubModelOrganizationResourceType",
    "ClubModelSocialMedia",
    "ClubModelStatus",
    "CompetitionDetailCompetitionsResponse",
    "CompetitionDetailResponseDefault",
    "CompetitionEntityStatisticsModel",
    "CompetitionEntityStatisticsModelCompetition",
    "CompetitionEntityStatisticsModelCompetitionResourceType",
    "CompetitionEntityStatisticsModelEntity",
    "CompetitionEntityStatisticsModelEntityResourceType",
    "CompetitionEntityStatisticsModelOrganization",
    "CompetitionEntityStatisticsModelOrganizationResourceType",
    "CompetitionEntityStatisticsModelStatistics",
    "CompetitionExternalIdsDetailCompetitionExternalIdsResponse",
    "CompetitionExternalIdsDetailResponseDefault",
    "CompetitionExternalIdsListCompetitionExternalIdsResponse",
    "CompetitionExternalIdsListResponseDefault",
    "CompetitionExternalIdsModel",
    "CompetitionExternalIdsModelCompetition",
    "CompetitionExternalIdsModelCompetitionResourceType",
    "CompetitionExternalIdsModelOrganization",
    "CompetitionExternalIdsModelOrganizationResourceType",
    "CompetitionListAgeGroup",
    "CompetitionListByLeagueIdAgeGroup",
    "CompetitionListByLeagueIdCompetitionsResponse",
    "CompetitionListByLeagueIdResponseDefault",
    "CompetitionListCompetitionsResponse",
    "CompetitionListResponseDefault",
    "CompetitionListSeasonStatusAgeGroup",
    "CompetitionListSeasonStatusCompetitionsSeasonStatusResponse",
    "CompetitionListSeasonStatusResponseDefault",
    "CompetitionListSeasonStatusSeasonStatus",
    "CompetitionListSeasonStatusSeasonVideoProduction",
    "CompetitionModel",
    "CompetitionModelAgeGroupType1",
    "CompetitionModelAgeGroupType2Type1",
    "CompetitionModelAgeGroupType3Type1",
    "CompetitionModelCompetitionHistoricalName",
    "CompetitionModelEventType",
    "CompetitionModelLeague",
    "CompetitionModelLeagueResourceType",
    "CompetitionModelOrganization",
    "CompetitionModelOrganizationResourceType",
    "CompetitionModelSocialMedia",
    "CompetitionPersonStatisticsModel",
    "CompetitionPersonStatisticsModelCompetition",
    "CompetitionPersonStatisticsModelCompetitionResourceType",
    "CompetitionPersonStatisticsModelOrganization",
    "CompetitionPersonStatisticsModelOrganizationResourceType",
    "CompetitionPersonStatisticsModelPerson",
    "CompetitionPersonStatisticsModelPersonResourceType",
    "CompetitionPersonStatisticsModelStatistics",
    "CompetitionSeasonStatusModel",
    "CompetitionSeasonStatusModelAgeGroupType1",
    "CompetitionSeasonStatusModelAgeGroupType2Type1",
    "CompetitionSeasonStatusModelAgeGroupType3Type1",
    "CompetitionSeasonStatusModelCompetitionHistoricalName",
    "CompetitionSeasonStatusModelEventType",
    "CompetitionSeasonStatusModelLeague",
    "CompetitionSeasonStatusModelLeagueResourceType",
    "CompetitionSeasonStatusModelOrganization",
    "CompetitionSeasonStatusModelOrganizationResourceType",
    "CompetitionSeasonStatusModelSocialMedia",
    "ConductDetailConductResponse",
    "ConductDetailResponseDefault",
    "ConductListConductResponse",
    "ConductListConductStatusType1",
    "ConductListConductStatusType2Type1",
    "ConductListConductStatusType3Type1",
    "ConductListConductType",
    "ConductListResponseDefault",
    "ConductModel",
    "ConductModelCompetition",
    "ConductModelCompetitionResourceType",
    "ConductModelConductPenaltyResult",
    "ConductModelConductPenaltyResultPenaltyType",
    "ConductModelConductTypeItem",
    "ConductModelEntity",
    "ConductModelEntityGroup",
    "ConductModelEntityGroupResourceType",
    "ConductModelEntityResourceType",
    "ConductModelFineStatusType1",
    "ConductModelFineStatusType2Type1",
    "ConductModelFineStatusType3Type1",
    "ConductModelFixture",
    "ConductModelFixtureResourceType",
    "ConductModelHearingStatusType1",
    "ConductModelHearingStatusType2Type1",
    "ConductModelHearingStatusType3Type1",
    "ConductModelOrganization",
    "ConductModelOrganizationResourceType",
    "ConductModelPeriodId",
    "ConductModelPerson",
    "ConductModelPersonResourceType",
    "ConductModelRoleType1",
    "ConductModelRoleType2Type1",
    "ConductModelRoleType3Type1",
    "ConductModelSeason",
    "ConductModelSeasonResourceType",
    "ConductModelStatusType1",
    "ConductModelStatusType2Type1",
    "ConductModelStatusType3Type1",
    "ConductModelVenue",
    "ConductModelVenueResourceType",
    "ConferenceDetailConferencesResponse",
    "ConferenceDetailResponseDefault",
    "ConferenceExternalIdsDetailConferenceExternalIdsResponse",
    "ConferenceExternalIdsDetailResponseDefault",
    "ConferenceExternalIdsListConferenceExternalIdsResponse",
    "ConferenceExternalIdsListResponseDefault",
    "ConferenceExternalIdsModel",
    "ConferenceExternalIdsModelConference",
    "ConferenceExternalIdsModelConferenceResourceType",
    "ConferenceExternalIdsModelOrganization",
    "ConferenceExternalIdsModelOrganizationResourceType",
    "ConferenceListConferencesResponse",
    "ConferenceListResponseDefault",
    "ConferenceModel",
    "ConferenceModelOrganization",
    "ConferenceModelOrganizationResourceType",
    "ConferenceModelSocialMedia",
    "CpsListCompetitionPersonStatisticsResponse",
    "CpsListFixtureType",
    "CpsListHomeAway",
    "CpsListResponseDefault",
    "CpsListWinLoss",
    "DivisionDetailDivisionsResponse",
    "DivisionDetailResponseDefault",
    "DivisionExternalIdsDetailDivisionExternalIdsResponse",
    "DivisionExternalIdsDetailResponseDefault",
    "DivisionExternalIdsListDivisionExternalIdsResponse",
    "DivisionExternalIdsListResponseDefault",
    "DivisionExternalIdsModel",
    "DivisionExternalIdsModelDivision",
    "DivisionExternalIdsModelDivisionResourceType",
    "DivisionExternalIdsModelOrganization",
    "DivisionExternalIdsModelOrganizationResourceType",
    "DivisionListDivisionsResponse",
    "DivisionListResponseDefault",
    "DivisionModel",
    "DivisionModelConference",
    "DivisionModelConferenceResourceType",
    "DivisionModelOrganization",
    "DivisionModelOrganizationResourceType",
    "DivisionModelSocialMedia",
    "EntityDetailEntitiesResponse",
    "EntityDetailResponseDefault",
    "EntityExternalIdsDetailEntityExternalIdsResponse",
    "EntityExternalIdsDetailResponseDefault",
    "EntityExternalIdsListEntityExternalIdsResponse",
    "EntityExternalIdsListResponseDefault",
    "EntityGroupDetailEntityGroupsResponse",
    "EntityGroupDetailResponseDefault",
    "EntityGroupExternalIdsDetailEntityGroupExternalIdsResponse",
    "EntityGroupExternalIdsDetailResponseDefault",
    "EntityGroupExternalIdsListEntityGroupExternalIdsResponse",
    "EntityGroupExternalIdsListResponseDefault",
    "EntityGroupListEntityGroupsResponse",
    "EntityGroupListResponseDefault",
    "EntityGroupListStatus",
    "EntityListAgeGroup",
    "EntityListByEntityGroupAgeGroup",
    "EntityListByEntityGroupDiscipline",
    "EntityListByEntityGroupEntitiesResponse",
    "EntityListByEntityGroupGender",
    "EntityListByEntityGroupResponseDefault",
    "EntityListByEntityGroupStandard",
    "EntityListByEntityGroupStatus",
    "EntityListDiscipline",
    "EntityListEntitiesResponse",
    "EntityListGender",
    "EntityListRepresentingCountry",
    "EntityListResponseDefault",
    "EntityListStandard",
    "EntityListStatus",
    "ErrorListModel",
    "ErrorListModelReason",
    "ErrorModel",
    "FesListBySeasonFixtureEntityStatisticsResponse",
    "FesListBySeasonResponseDefault",
    "FesListFixtureEntityStatisticsResponse",
    "FesListliveFixtureEntityStatisticsResponse",
    "FesListliveResponseDefault",
    "FesListperiodBySeasonFixtureEntityStatisticsPeriodsResponse",
    "FesListperiodBySeasonResponseDefault",
    "FesListperiodFixtureEntityStatisticsPeriodsResponse",
    "FesListperiodliveFixtureEntityStatisticsPeriodsResponse",
    "FesListperiodlivePeriodId",
    "FesListperiodliveResponseDefault",
    "FesListperiodPeriodId",
    "FesListperiodResponseDefault",
    "FesListResponseDefault",
    "FixtureByCompetitionListCompetitorType",
    "FixtureByCompetitionListDiscipline",
    "FixtureByCompetitionListFixtureType",
    "FixtureByCompetitionListResponseDefault",
    "FixtureByCompetitionListStatus",
    "FixtureByEntityAllSeasonsListCompetitorType",
    "FixtureByEntityAllSeasonsListFixtureType",
    "FixtureByEntityAllSeasonsListResponseDefault",
    "FixtureByEntityAllSeasonsListStatus",
    "FixtureByEntityListCompetitorType",
    "FixtureByEntityListDiscipline",
    "FixtureByEntityListFixtureType",
    "FixtureByEntityListResponseDefault",
    "FixtureByEntityListStatus",
    "FixtureDetailFixturesResponse",
    "FixtureDetailResponseDefault",
    "FixtureEntitiesDetailFixtureEntitiesResponse",
    "FixtureEntitiesDetailResponseDefault",
    "FixtureEntitiesListFixtureEntitiesResponse",
    "FixtureEntitiesListResponseDefault",
    "FixtureExternalIdsDetailFixtureExternalIdsResponse",
    "FixtureExternalIdsDetailResponseDefault",
    "FixtureExternalIdsListFixtureExternalIdsResponse",
    "FixtureExternalIdsListResponseDefault",
    "FixtureListCompetitorType",
    "FixtureListDiscipline",
    "FixtureListFixturesResponse",
    "FixtureListFixtureType",
    "FixtureListResponseDefault",
    "FixtureListStatus",
    "FixtureListStatusNot",
    "FixtureLiveSummaryModel",
    "FixtureLiveSummaryModelClockInformation",
    "FixtureLiveSummaryModelInformationPerEntity",
    "FixtureLiveSummaryModelStatusInformation",
    "FixturePBPEventModel",
    "FixturePBPEventModelClass",
    "FixturePBPEventModelCurrentScores",
    "FixturePBPEventModelEntity",
    "FixturePBPEventModelEntityResourceType",
    "FixturePBPEventModelFixture",
    "FixturePBPEventModelFixtureResourceType",
    "FixturePBPEventModelOrganization",
    "FixturePBPEventModelOrganizationResourceType",
    "FixturePBPEventModelPeriodId",
    "FixturePBPEventModelPerson",
    "FixturePBPEventModelPersonResourceType",
    "FixturePbpExportPeriodId",
    "FixturePbpExportResponseDefault",
    "FixturePbpExportSuccessResponse",
    "FixturePbpExternalExportPeriodId",
    "FixturePbpExternalExportResponseDefault",
    "FixturePbpExternalExportSuccessResponse",
    "FixturePbpExternalListFixturePbpExternalResponse",
    "FixturePbpExternalListLiveFixturePbpExternalResponse",
    "FixturePbpExternalListLivePeriodId",
    "FixturePbpExternalListLiveResponseDefault",
    "FixturePbpExternalListPeriodId",
    "FixturePbpExternalListResponseDefault",
    "FixturePbpExternalModel",
    "FixturePbpExternalModelEventDetails",
    "FixturePbpExternalModelFixture",
    "FixturePbpExternalModelFixtureResourceType",
    "FixturePbpExternalModelOrganization",
    "FixturePbpExternalModelOrganizationResourceType",
    "FixturePbpExternalModelPeriodId",
    "FixturePbpListFixturePbpEventResponse",
    "FixturePbpListLiveFixturePbpEventResponse",
    "FixturePbpListLivePeriodId",
    "FixturePbpListLiveResponseDefault",
    "FixturePbpListPeriodId",
    "FixturePbpListResponseDefault",
    "FixturePbpModel",
    "FixturePbpModelEventDetails",
    "FixturePbpModelFixture",
    "FixturePbpModelFixtureResourceType",
    "FixturePbpModelOrganization",
    "FixturePbpModelOrganizationResourceType",
    "FixturePbpModelPeriodId",
    "FixturePersonsDetailFixturePersonsResponse",
    "FixturePersonsDetailResponseDefault",
    "FixturePersonsListFixturePersonsResponse",
    "FixturePersonsListResponseDefault",
    "FixtureProfilesDetailFixtureProfilesResponse",
    "FixtureProfilesDetailResponseDefault",
    "FixtureProfilesForFixtureFixtureProfilesResponse",
    "FixtureProfilesForFixtureResponseDefault",
    "FixtureProfilesListFixtureProfilesResponse",
    "FixtureProfilesListResponseDefault",
    "FixtureProgressionModel",
    "FixtureProgressionModelFixture",
    "FixtureProgressionModelFixtureResourceType",
    "FixtureProgressionModelOrganization",
    "FixtureProgressionModelOrganizationResourceType",
    "FixtureProgressionModelSeason",
    "FixtureProgressionModelSeasonResourceType",
    "FixtureProgressionsDetailFixtureProgressionsResponse",
    "FixtureProgressionsDetailResponseDefault",
    "FixtureProgressionsListFixtureProgressionsResponse",
    "FixtureProgressionsListResponseDefault",
    "FixtureRosterDetailFixtureRosterResponse",
    "FixtureRosterDetailResponseDefault",
    "FixtureRosterListByEntityFixtureRosterResponse",
    "FixtureRosterListByEntityResponseDefault",
    "FixtureRosterListFixtureRosterResponse",
    "FixtureRosterListResponseDefault",
    "FlsListFixtureLiveSummaryResponse",
    "FlsListResponseDefault",
    "FpsListBySeasonFixturePersonStatisticsResponse",
    "FpsListBySeasonResponseDefault",
    "FpsListFixturePersonStatisticsResponse",
    "FpsListliveFixturePersonStatisticsResponse",
    "FpsListliveResponseDefault",
    "FpsListResponseDefault",
    "FpspListBySeasonFixturePersonStatisticsPeriodsResponse",
    "FpspListBySeasonResponseDefault",
    "FpspListperiodFixturePersonStatisticsPeriodsResponse",
    "FpspListperiodliveFixturePersonStatisticsPeriodsResponse",
    "FpspListperiodlivePeriodId",
    "FpspListperiodliveResponseDefault",
    "FpspListperiodPeriodId",
    "FpspListperiodResponseDefault",
    "GameLogEntityModel",
    "GameLogEntityModelEntity",
    "GameLogEntityModelEntityResourceType",
    "GameLogEntityModelFixture",
    "GameLogEntityModelFixtureResourceType",
    "GameLogEntityModelOrganization",
    "GameLogEntityModelOrganizationResourceType",
    "GameLogEntityModelPeriodId",
    "GameLogEntityModelStatistics",
    "GamelogListentityFixtureType",
    "GamelogListentityGameLogEntityResponse",
    "GamelogListentityHomeAway",
    "GamelogListentityResponseDefault",
    "GamelogListentityWinLoss",
    "GamelogListpersonFixtureType",
    "GamelogListpersonGameLogPersonResponse",
    "GamelogListpersonHomeAway",
    "GamelogListpersonResponseDefault",
    "GamelogListpersonWinLoss",
    "GameLogPersonModel",
    "GameLogPersonModelEntity",
    "GameLogPersonModelEntityResourceType",
    "GameLogPersonModelFixture",
    "GameLogPersonModelFixtureResourceType",
    "GameLogPersonModelOrganization",
    "GameLogPersonModelOrganizationResourceType",
    "GameLogPersonModelPeriodId",
    "GameLogPersonModelPerson",
    "GameLogPersonModelPersonResourceType",
    "GameLogPersonModelPositionType1",
    "GameLogPersonModelPositionType2Type1",
    "GameLogPersonModelPositionType3Type1",
    "GameLogPersonModelStatistics",
    "HeadToHeadEntityModel",
    "HeadToHeadEntityModelCompetition",
    "HeadToHeadEntityModelCompetitionResourceType",
    "HeadToHeadEntityModelFixture",
    "HeadToHeadEntityModelFixtureResourceType",
    "HeadToHeadEntityModelOrganization",
    "HeadToHeadEntityModelOrganizationResourceType",
    "HeadToHeadEntityModelSeason",
    "HeadToHeadEntityModelSeasonResourceType",
    "HeadToHeadListFixturesFixtureType",
    "HeadToHeadListFixturesHeadToHeadEntityResponse",
    "HeadToHeadListFixturesMulitpleCompetitionsFixtureType",
    "HeadToHeadListFixturesMulitpleCompetitionsHeadToHeadEntityResponse",
    "HeadToHeadListFixturesMulitpleCompetitionsResponseDefault",
    "HeadToHeadListFixturesMulitpleCompetitionsStatus",
    "HeadToHeadListFixturesMulitpleCompetitionsStatusNot",
    "HeadToHeadListFixturesResponseDefault",
    "HeadToHeadListFixturesStatus",
    "HeadToHeadListFixturesStatusNot",
    "ImagesDetailImagesResponse",
    "ImagesDetailResponseDefault",
    "ImagesForFixtureListBaseType",
    "ImagesForFixtureListImagesResponse",
    "ImagesForFixtureListImageType",
    "ImagesForFixtureListRating",
    "ImagesForFixtureListResponseDefault",
    "ImagesListBaseType",
    "ImagesListIdBaseType",
    "ImagesListIdImagesResponse",
    "ImagesListIdImageType",
    "ImagesListIdRating",
    "ImagesListIdResponseDefault",
    "ImagesListIdSecondaryBaseType",
    "ImagesListIdSecondaryImagesResponse",
    "ImagesListIdSecondaryImageType",
    "ImagesListIdSecondaryRating",
    "ImagesListIdSecondaryResponseDefault",
    "ImagesListIdSecondarySecondaryType",
    "ImagesListImagesResponse",
    "ImagesListImageType",
    "ImagesListOrganizationBaseType",
    "ImagesListOrganizationImagesResponse",
    "ImagesListOrganizationImageType",
    "ImagesListOrganizationRating",
    "ImagesListOrganizationResponseDefault",
    "ImagesListRating",
    "ImagesListResponseDefault",
    "ImagesListSecondaryBaseType",
    "ImagesListSecondaryImagesResponse",
    "ImagesListSecondaryImageType",
    "ImagesListSecondaryRating",
    "ImagesListSecondaryResponseDefault",
    "ImagesListSecondarySecondaryType",
    "ImagesModel",
    "ImagesModelBaseType",
    "ImagesModelFileType",
    "ImagesModelImageType",
    "ImagesModelOrganization",
    "ImagesModelOrganizationResourceType",
    "ImagesModelRating",
    "ImagesModelSecondaryTypeType1",
    "ImagesModelSecondaryTypeType2Type1",
    "ImagesModelSecondaryTypeType3Type1",
    "IncludedData",
    "IncludedDataResources",
    "IncludedDataResourcesAdditionalProperty",
    "LeaderCriteriaDetailLeaderCriteriaResponse",
    "LeaderCriteriaDetailResponseDefault",
    "LeaderCriteriaListLeaderCriteriaResponse",
    "LeaderCriteriaListResponseDefault",
    "LeaderCriteriaModel",
    "LeaderCriteriaModelOrganization",
    "LeaderCriteriaModelOrganizationResourceType",
    "LeaderQualifierModel",
    "LeaderQualifierModelComparisonType",
    "LeaderQualifierModelLeadersCriteria",
    "LeaderQualifierModelLeadersCriteriaResourceType",
    "LeaderQualifierModelOrganization",
    "LeaderQualifierModelOrganizationResourceType",
    "LeaderQualifiersDetailLeaderQualifiersResponse",
    "LeaderQualifiersDetailResponseDefault",
    "LeaderQualifiersListLeaderQualifiersResponse",
    "LeaderQualifiersListResponseDefault",
    "LeagueDetailLeaguesResponse",
    "LeagueDetailResponseDefault",
    "LeagueExternalIdsDetailLeagueExternalIdsResponse",
    "LeagueExternalIdsDetailResponseDefault",
    "LeagueExternalIdsListLeagueExternalIdsResponse",
    "LeagueExternalIdsListResponseDefault",
    "LeagueExternalIdsModel",
    "LeagueExternalIdsModelLeague",
    "LeagueExternalIdsModelLeagueResourceType",
    "LeagueExternalIdsModelOrganization",
    "LeagueExternalIdsModelOrganizationResourceType",
    "LeagueListLeaguesResponse",
    "LeagueListRegionType",
    "LeagueListResponseDefault",
    "LeagueModel",
    "LeagueModelOrganization",
    "LeagueModelOrganizationResourceType",
    "LeagueModelRegionType",
    "LeagueModelSocialMedia",
    "MatchExternalIdsModel",
    "MatchExternalIdsModelFixture",
    "MatchExternalIdsModelFixtureResourceType",
    "MatchExternalIdsModelOrganization",
    "MatchExternalIdsModelOrganizationResourceType",
    "MatchModel",
    "MatchModelBroadcasts",
    "MatchModelBroadcastsBroadcastType",
    "MatchModelCompetitorType",
    "MatchModelDisciplineType1",
    "MatchModelDisciplineType2Type1",
    "MatchModelDisciplineType3Type1",
    "MatchModelEnvironmentalDetails",
    "MatchModelFixtureProfile",
    "MatchModelFixtureProfileResourceType",
    "MatchModelFixtureType",
    "MatchModelMatchCompetitor",
    "MatchModelMatchCompetitorResultStatus",
    "MatchModelMatchCompetitorRosterStatus",
    "MatchModelMaximumPeriodTypeUsedType1",
    "MatchModelMaximumPeriodTypeUsedType2Type1",
    "MatchModelMaximumPeriodTypeUsedType3Type1",
    "MatchModelOrganization",
    "MatchModelOrganizationResourceType",
    "MatchModelPool",
    "MatchModelPoolResourceType",
    "MatchModelPracticeDrillTypeType1",
    "MatchModelPracticeDrillTypeType2Type1",
    "MatchModelPracticeDrillTypeType3Type1",
    "MatchModelRound",
    "MatchModelRoundResourceType",
    "MatchModelSeason",
    "MatchModelSeasonResourceType",
    "MatchModelSeries",
    "MatchModelSeriesResourceType",
    "MatchModelSocialMedia",
    "MatchModelStage",
    "MatchModelStageResourceType",
    "MatchModelStatus",
    "MatchModelVenue",
    "MatchModelVenueResourceType",
    "MatchPersonsModel",
    "MatchPersonsModelEntityGroup",
    "MatchPersonsModelEntityGroupResourceType",
    "MatchPersonsModelFixture",
    "MatchPersonsModelFixtureResourceType",
    "MatchPersonsModelOrganization",
    "MatchPersonsModelOrganizationResourceType",
    "MatchPersonsModelPerson",
    "MatchPersonsModelPersonResourceType",
    "MatchPersonsModelResultStatus",
    "MatchPersonsModelUniform",
    "MatchPersonsModelUniformResourceType",
    "MatchPersonStatisticsModel",
    "MatchPersonStatisticsModelEntity",
    "MatchPersonStatisticsModelEntityResourceType",
    "MatchPersonStatisticsModelFixture",
    "MatchPersonStatisticsModelFixtureResourceType",
    "MatchPersonStatisticsModelOrganization",
    "MatchPersonStatisticsModelOrganizationResourceType",
    "MatchPersonStatisticsModelPerson",
    "MatchPersonStatisticsModelPersonResourceType",
    "MatchPersonStatisticsModelPositionType1",
    "MatchPersonStatisticsModelPositionType2Type1",
    "MatchPersonStatisticsModelPositionType3Type1",
    "MatchPersonStatisticsModelStatistics",
    "MatchPersonStatisticsPeriodsModel",
    "MatchPersonStatisticsPeriodsModelEntity",
    "MatchPersonStatisticsPeriodsModelEntityResourceType",
    "MatchPersonStatisticsPeriodsModelFixture",
    "MatchPersonStatisticsPeriodsModelFixtureResourceType",
    "MatchPersonStatisticsPeriodsModelOrganization",
    "MatchPersonStatisticsPeriodsModelOrganizationResourceType",
    "MatchPersonStatisticsPeriodsModelPeriodId",
    "MatchPersonStatisticsPeriodsModelPerson",
    "MatchPersonStatisticsPeriodsModelPersonResourceType",
    "MatchPersonStatisticsPeriodsModelStatistics",
    "MatchProfilesModel",
    "MatchProfilesModelMatchProfileConfiguration",
    "MatchProfilesModelMatchProfileConfigurationMatchRolesItem",
    "MatchProfilesModelMatchProfileConfigurationTypeOfCardsItem",
    "MatchProfilesModelOrganization",
    "MatchProfilesModelOrganizationResourceType",
    "MatchRosterModel",
    "MatchRosterModelEntity",
    "MatchRosterModelEntityResourceType",
    "MatchRosterModelFixture",
    "MatchRosterModelFixtureResourceType",
    "MatchRosterModelOrganization",
    "MatchRosterModelOrganizationResourceType",
    "MatchRosterModelPerson",
    "MatchRosterModelPersonResourceType",
    "MatchRosterModelPositionType1",
    "MatchRosterModelPositionType2Type1",
    "MatchRosterModelPositionType3Type1",
    "MatchTeamPeriodStatisticsModel",
    "MatchTeamPeriodStatisticsModelEntity",
    "MatchTeamPeriodStatisticsModelEntityResourceType",
    "MatchTeamPeriodStatisticsModelFixture",
    "MatchTeamPeriodStatisticsModelFixtureResourceType",
    "MatchTeamPeriodStatisticsModelOrganization",
    "MatchTeamPeriodStatisticsModelOrganizationResourceType",
    "MatchTeamPeriodStatisticsModelPeriodId",
    "MatchTeamPeriodStatisticsModelStatistics",
    "MatchTeamsModel",
    "MatchTeamsModelConference",
    "MatchTeamsModelConferenceResourceType",
    "MatchTeamsModelDivision",
    "MatchTeamsModelDivisionResourceType",
    "MatchTeamsModelEntity",
    "MatchTeamsModelEntityResourceType",
    "MatchTeamsModelFixture",
    "MatchTeamsModelFixtureResourceType",
    "MatchTeamsModelOrganization",
    "MatchTeamsModelOrganizationResourceType",
    "MatchTeamsModelResultStatus",
    "MatchTeamsModelRosterStatus",
    "MatchTeamsModelUniform",
    "MatchTeamsModelUniformResourceType",
    "MatchTeamStatisticsModel",
    "MatchTeamStatisticsModelEntity",
    "MatchTeamStatisticsModelEntityResourceType",
    "MatchTeamStatisticsModelFixture",
    "MatchTeamStatisticsModelFixtureResourceType",
    "MatchTeamStatisticsModelOrganization",
    "MatchTeamStatisticsModelOrganizationResourceType",
    "MatchTeamStatisticsModelStatistics",
    "Model",
    "OrganizationDetailOrganizationsResponse",
    "OrganizationDetailResponseDefault",
    "OrganizationFixtureListCompetitorType",
    "OrganizationFixtureListDiscipline",
    "OrganizationFixtureListFixturesResponse",
    "OrganizationFixtureListFixtureType",
    "OrganizationFixtureListResponseDefault",
    "OrganizationFixtureListStatus",
    "OrganizationFixtureListStatusNot",
    "OrganizationListOrganizationsResponse",
    "OrganizationListRegionType",
    "OrganizationListResponseDefault",
    "OrganizationModel",
    "OrganizationModelRegionType",
    "OrggroupCompetitionListCompetitionsResponse",
    "OrggroupCompetitionListResponseDefault",
    "OrggroupFixtureDetailFixturesResponse",
    "OrggroupFixtureDetailResponseDefault",
    "OrggroupFixtureListCompetitorType",
    "OrggroupFixtureListFixturesResponse",
    "OrggroupFixtureListFixtureType",
    "OrggroupFixtureListResponseDefault",
    "OrggroupFixtureListStatus",
    "PartnersGetBlankModelGetBody",
    "PartnersGetBlankModelResponse",
    "PartnersGetResponseDefault",
    "PersonDetailPersonsResponse",
    "PersonDetailResponseDefault",
    "PersonExternalIdsDetailPersonExternalIdsResponse",
    "PersonExternalIdsDetailResponseDefault",
    "PersonExternalIdsListPersonExternalIdsResponse",
    "PersonExternalIdsListResponseDefault",
    "PersonExternalIdsModel",
    "PersonExternalIdsModelOrganization",
    "PersonExternalIdsModelOrganizationResourceType",
    "PersonExternalIdsModelPerson",
    "PersonExternalIdsModelPersonResourceType",
    "PersonListGender",
    "PersonListPersonsResponse",
    "PersonListRepresentingCountry",
    "PersonListResponseDefault",
    "PersonListStatus",
    "PersonModel",
    "PersonModelAdditionalNamesType0",
    "PersonModelAdditionalNamesType0AdditionalProperty",
    "PersonModelGender",
    "PersonModelOrganization",
    "PersonModelOrganizationResourceType",
    "PersonModelPersonAdditionalDetails",
    "PersonModelPersonAdditionalDetailsDominantFoot",
    "PersonModelPersonAdditionalDetailsDominantHand",
    "PersonModelPersonHistoricalName",
    "PersonModelSocialMedia",
    "PersonModelStatus",
    "PoolModel",
    "PoolModelOrganization",
    "PoolModelOrganizationResourceType",
    "PoolModelSeason",
    "PoolModelSeasonResourceType",
    "PoolModelStage",
    "PoolModelStageResourceType",
    "PssListAgeGroup",
    "PssListFixtureType",
    "PssListRepresentation",
    "PssListResponseDefault",
    "PssListSeasonPersonStatisticsResponse",
    "PssListSeasonType",
    "PssListStandard",
    "PstsListAgeGroup",
    "PstsListFixtureType",
    "PstsListRepresentation",
    "PstsListResponseDefault",
    "PstsListSeasonPersonTotalStatisticsResponse",
    "PstsListSeasonType",
    "PstsListStandard",
    "ResponseLinks",
    "ResponseMetaData",
    "RoleModel",
    "RoleModelEntity",
    "RoleModelEntityGroup",
    "RoleModelEntityGroupResourceType",
    "RoleModelEntityResourceType",
    "RoleModelFixture",
    "RoleModelFixtureResourceType",
    "RoleModelOrganization",
    "RoleModelOrganizationResourceType",
    "RoleModelPerson",
    "RoleModelPersonResourceType",
    "RoleModelRoleType1",
    "RoleModelSeason",
    "RoleModelSeasonResourceType",
    "RoleModelStatus",
    "RolesDetailResponseDefault",
    "RolesDetailRolesResponse",
    "RolesListByFixtureResponseDefault",
    "RolesListByFixtureRole",
    "RolesListByFixtureRolesResponse",
    "RolesListByFixtureStatus",
    "RolesListFixturesResponseDefault",
    "RolesListFixturesRole",
    "RolesListFixturesRolesResponse",
    "RolesListFixturesStatus",
    "RolesListNonFixturesResponseDefault",
    "RolesListNonFixturesRole",
    "RolesListNonFixturesRolesResponse",
    "RolesListNonFixturesStatus",
    "RoundModel",
    "RoundModelOrganization",
    "RoundModelOrganizationResourceType",
    "RoundModelPool",
    "RoundModelPoolResourceType",
    "RoundModelSeason",
    "RoundModelSeasonResourceType",
    "RoundModelStage",
    "RoundModelStageResourceType",
    "SeasonDetailResponseDefault",
    "SeasonDetailSeasonsResponse",
    "SeasonEntitiesDetailResponseDefault",
    "SeasonEntitiesDetailSeasonEntitiesResponse",
    "SeasonEntitiesListResponseDefault",
    "SeasonEntitiesListSeasonEntitiesListResponse",
    "SeasonEntitiesModel",
    "SeasonEntitiesModelConference",
    "SeasonEntitiesModelConferenceResourceType",
    "SeasonEntitiesModelDivision",
    "SeasonEntitiesModelDivisionResourceType",
    "SeasonEntitiesModelEntity",
    "SeasonEntitiesModelEntityResourceType",
    "SeasonEntitiesModelOrganization",
    "SeasonEntitiesModelOrganizationResourceType",
    "SeasonEntitiesModelRosterStatus",
    "SeasonEntitiesModelSeason",
    "SeasonEntitiesModelSeasonResourceType",
    "SeasonEntitiesModelStatus",
    "SeasonEntityListByMultipleSeasonsResponseDefault",
    "SeasonEntityListByMultipleSeasonsSeasonEntitiesListResponse",
    "SeasonEntityListResponseDefault",
    "SeasonEntityListSeasonEntitiesListResponse",
    "SeasonEntityStatisticsModel",
    "SeasonEntityStatisticsModelCompetition",
    "SeasonEntityStatisticsModelCompetitionResourceType",
    "SeasonEntityStatisticsModelEntity",
    "SeasonEntityStatisticsModelEntityResourceType",
    "SeasonEntityStatisticsModelOrganization",
    "SeasonEntityStatisticsModelOrganizationResourceType",
    "SeasonEntityStatisticsModelPeriodId",
    "SeasonEntityStatisticsModelSeason",
    "SeasonEntityStatisticsModelSeasonResourceType",
    "SeasonEntityStatisticsModelStatistics",
    "SeasonExternalIdsDetailResponseDefault",
    "SeasonExternalIdsDetailSeasonExternalIdsResponse",
    "SeasonExternalIdsListResponseDefault",
    "SeasonExternalIdsListSeasonExternalIdsResponse",
    "SeasonExternalIdsModel",
    "SeasonExternalIdsModelOrganization",
    "SeasonExternalIdsModelOrganizationResourceType",
    "SeasonExternalIdsModelSeason",
    "SeasonExternalIdsModelSeasonResourceType",
    "SeasonFixtureStagesPoolsListFixtureType",
    "SeasonFixtureStagesPoolsListResponseDefault",
    "SeasonFixtureStagesPoolsListSeasonFixtureStagesPoolsListResponse",
    "SeasonFixtureStagesPoolsModel",
    "SeasonFixtureStagesPoolsModelFixtureType",
    "SeasonFixtureStagesPoolsModelOrganization",
    "SeasonFixtureStagesPoolsModelOrganizationResourceType",
    "SeasonFixtureStagesPoolsModelPool",
    "SeasonFixtureStagesPoolsModelPoolResourceType",
    "SeasonFixtureStagesPoolsModelSeason",
    "SeasonFixtureStagesPoolsModelSeasonResourceType",
    "SeasonFixtureStagesPoolsModelStage",
    "SeasonFixtureStagesPoolsModelStageResourceType",
    "SeasonLeaderSummaryModel",
    "SeasonListAgeGroup",
    "SeasonListByOrganizationAgeGroup",
    "SeasonListByOrganizationDiscipline",
    "SeasonListByOrganizationEventType",
    "SeasonListByOrganizationGender",
    "SeasonListByOrganizationRepresentation",
    "SeasonListByOrganizationResponseDefault",
    "SeasonListByOrganizationSeasonsResponse",
    "SeasonListByOrganizationSeasonType",
    "SeasonListByOrganizationStandard",
    "SeasonListByOrganizationStatus",
    "SeasonListByOrganizationVideoProduction",
    "SeasonListDiscipline",
    "SeasonListEventType",
    "SeasonListGender",
    "SeasonListRepresentation",
    "SeasonListResponseDefault",
    "SeasonListSeasonsResponse",
    "SeasonListSeasonType",
    "SeasonListStandard",
    "SeasonListStatus",
    "SeasonListVideoProduction",
    "SeasonModel",
    "SeasonModelAgeGroup",
    "SeasonModelCompetition",
    "SeasonModelCompetitionResourceType",
    "SeasonModelDisciplineType1",
    "SeasonModelDisciplineType2Type1",
    "SeasonModelDisciplineType3Type1",
    "SeasonModelEventType",
    "SeasonModelFixtureProfile",
    "SeasonModelFixtureProfileResourceType",
    "SeasonModelGender",
    "SeasonModelLeadersCriteria",
    "SeasonModelLeadersCriteriaResourceType",
    "SeasonModelOrganization",
    "SeasonModelOrganizationResourceType",
    "SeasonModelPromotionRelegationRulesType0Item",
    "SeasonModelPromotionRelegationRulesType0ItemRuleType",
    "SeasonModelRepresentation",
    "SeasonModelSeasonConfiguration",
    "SeasonModelSEASONROSTERConfiguration",
    "SeasonModelSEASONROSTERConfigurationSeasonRosterStatusAllowedItem",
    "SeasonModelSeasonType",
    "SeasonModelSocialMedia",
    "SeasonModelStandard",
    "SeasonModelStandingConfiguration",
    "SeasonModelStandingConfigurationResourceType",
    "SeasonModelStatus",
    "SeasonModelVideoProduction",
    "SeasonPersonBaseStatisticsModel",
    "SeasonPersonBaseStatisticsModelCompetitorType",
    "SeasonPersonBaseStatisticsModelEntity",
    "SeasonPersonBaseStatisticsModelEntityResourceType",
    "SeasonPersonBaseStatisticsModelFixtureType",
    "SeasonPersonBaseStatisticsModelOrganization",
    "SeasonPersonBaseStatisticsModelOrganizationResourceType",
    "SeasonPersonBaseStatisticsModelPerson",
    "SeasonPersonBaseStatisticsModelPersonResourceType",
    "SeasonPersonBaseStatisticsModelSeason",
    "SeasonPersonBaseStatisticsModelSeasonResourceType",
    "SeasonPersonBaseStatisticsModelStatistics",
    "SeasonPersonListResponseDefault",
    "SeasonPersonListSeasonPersonsListResponse",
    "SEASONPERSONPlacingsModel",
    "SEASONPERSONPlacingsModelOrganization",
    "SEASONPERSONPlacingsModelOrganizationResourceType",
    "SEASONPERSONPlacingsModelPerson",
    "SEASONPERSONPlacingsModelPersonResourceType",
    "SEASONPERSONPlacingsModelSeason",
    "SEASONPERSONPlacingsModelSeasonResourceType",
    "SeasonPersonsDetailResponseDefault",
    "SeasonPersonsListResponseDefault",
    "SeasonPersonsListSeasonPersonsListResponse",
    "SeasonPersonsModel",
    "SeasonPersonsModelEntityGroup",
    "SeasonPersonsModelEntityGroupResourceType",
    "SeasonPersonsModelOrganization",
    "SeasonPersonsModelOrganizationResourceType",
    "SeasonPersonsModelPerson",
    "SeasonPersonsModelPersonResourceType",
    "SeasonPersonsModelSeason",
    "SeasonPersonsModelSeasonResourceType",
    "SeasonPersonsModelStatus",
    "SeasonPersonStatisticsModel",
    "SeasonPersonStatisticsModelCompetition",
    "SeasonPersonStatisticsModelCompetitionResourceType",
    "SeasonPersonStatisticsModelEntity",
    "SeasonPersonStatisticsModelEntityResourceType",
    "SeasonPersonStatisticsModelOrganization",
    "SeasonPersonStatisticsModelOrganizationResourceType",
    "SeasonPersonStatisticsModelPerson",
    "SeasonPersonStatisticsModelPersonResourceType",
    "SeasonPersonStatisticsModelSeason",
    "SeasonPersonStatisticsModelSeasonResourceType",
    "SeasonPersonStatisticsModelStatistics",
    "SeasonPersonTotalStatisticsModel",
    "SeasonPersonTotalStatisticsModelCompetition",
    "SeasonPersonTotalStatisticsModelCompetitionResourceType",
    "SeasonPersonTotalStatisticsModelOrganization",
    "SeasonPersonTotalStatisticsModelOrganizationResourceType",
    "SeasonPersonTotalStatisticsModelPerson",
    "SeasonPersonTotalStatisticsModelPersonResourceType",
    "SeasonPersonTotalStatisticsModelSeason",
    "SeasonPersonTotalStatisticsModelSeasonResourceType",
    "SeasonPersonTotalStatisticsModelStatistics",
    "SeasonPoolDetailResponseDefault",
    "SeasonPoolDetailSeasonPoolsResponse",
    "SeasonPoolListResponseDefault",
    "SeasonPoolListSeasonPoolsResponse",
    "SeasonRosterDetailResponseDefault",
    "SeasonRosterDetailSeasonRosterResponse",
    "SeasonRosterDetailStatus",
    "SeasonRosterListByEntityResponseDefault",
    "SeasonRosterListByEntitySeasonRosterResponse",
    "SeasonRosterListByEntityStatus",
    "SeasonRosterListResponseDefault",
    "SeasonRosterListSeasonRosterResponse",
    "SeasonRosterListStatus",
    "SeasonRosterModel",
    "SeasonRosterModelConference",
    "SeasonRosterModelConferenceResourceType",
    "SeasonRosterModelDivision",
    "SeasonRosterModelDivisionResourceType",
    "SeasonRosterModelEntity",
    "SeasonRosterModelEntityGroup",
    "SeasonRosterModelEntityGroupResourceType",
    "SeasonRosterModelEntityResourceType",
    "SeasonRosterModelOrganization",
    "SeasonRosterModelOrganizationResourceType",
    "SeasonRosterModelPerson",
    "SeasonRosterModelPersonResourceType",
    "SeasonRosterModelPositionType1",
    "SeasonRosterModelPositionType2Type1",
    "SeasonRosterModelPositionType3Type1",
    "SeasonRosterModelSeason",
    "SeasonRosterModelSeasonResourceType",
    "SeasonRosterModelStatus",
    "SeasonRoundDetailResponseDefault",
    "SeasonRoundDetailSeasonRoundsResponse",
    "SeasonRoundListResponseDefault",
    "SeasonRoundListSeasonRoundsResponse",
    "SeasonSeriesDetailResponseDefault",
    "SeasonSeriesDetailSeasonSeriesResponse",
    "SeasonSeriesListResponseDefault",
    "SeasonSeriesListSeasonSeriesResponse",
    "SeasonSeriesListSeriesType",
    "SeasonsRosterListByEntityResponseDefault",
    "SeasonsRosterListByEntitySeasonRosterResponse",
    "SeasonsRosterListByEntityStatus",
    "SeasonStageDetailResponseDefault",
    "SeasonStageDetailSeasonStagesResponse",
    "SeasonStageListResponseDefault",
    "SeasonStageListSeasonStagesResponse",
    "SeasonStageModel",
    "SeasonStageModelOrganization",
    "SeasonStageModelOrganizationResourceType",
    "SeasonStageModelSeason",
    "SeasonStageModelSeasonResourceType",
    "SeasonStandingsStagesPoolsListFixtureType",
    "SeasonStandingsStagesPoolsListResponseDefault",
    "SeasonStandingsStagesPoolsListSeasonStandingsStagesPoolsListResponse",
    "SeasonStandingsStagesPoolsModel",
    "SeasonStandingsStagesPoolsModelOrganization",
    "SeasonStandingsStagesPoolsModelOrganizationResourceType",
    "SeasonStandingsStagesPoolsModelPool",
    "SeasonStandingsStagesPoolsModelPoolResourceType",
    "SeasonStandingsStagesPoolsModelSeason",
    "SeasonStandingsStagesPoolsModelSeasonResourceType",
    "SeasonStandingsStagesPoolsModelStage",
    "SeasonStandingsStagesPoolsModelStageResourceType",
    "SeasonTeamBaseStatisticsModel",
    "SeasonTeamBaseStatisticsModelCompetitorType",
    "SeasonTeamBaseStatisticsModelEntity",
    "SeasonTeamBaseStatisticsModelEntityResourceType",
    "SeasonTeamBaseStatisticsModelFixtureType",
    "SeasonTeamBaseStatisticsModelOrganization",
    "SeasonTeamBaseStatisticsModelOrganizationResourceType",
    "SeasonTeamBaseStatisticsModelSeason",
    "SeasonTeamBaseStatisticsModelSeasonResourceType",
    "SeasonTeamBaseStatisticsModelStatistics",
    "SEASONTEAMPlacingsModel",
    "SEASONTEAMPlacingsModelEntity",
    "SEASONTEAMPlacingsModelEntityResourceType",
    "SEASONTEAMPlacingsModelOrganization",
    "SEASONTEAMPlacingsModelOrganizationResourceType",
    "SEASONTEAMPlacingsModelSeason",
    "SEASONTEAMPlacingsModelSeasonResourceType",
    "SeasonTeamsModel",
    "SeasonTeamsModelConference",
    "SeasonTeamsModelConferenceResourceType",
    "SeasonTeamsModelDivision",
    "SeasonTeamsModelDivisionResourceType",
    "SeasonTeamsModelEntity",
    "SeasonTeamsModelEntityResourceType",
    "SeasonTeamsModelOrganization",
    "SeasonTeamsModelOrganizationResourceType",
    "SeasonTeamsModelRosterStatus",
    "SeasonTeamsModelSeason",
    "SeasonTeamsModelSeasonResourceType",
    "SeasonTeamsModelStatus",
    "SeasonVenuesListResponseDefault",
    "SeasonVenuesListSeasonVenuesListResponse",
    "SeasonVenuesModel",
    "SeasonVenuesModelOrganization",
    "SeasonVenuesModelOrganizationResourceType",
    "SeasonVenuesModelSeason",
    "SeasonVenuesModelSeasonResourceType",
    "SeasonVenuesModelSeasonVenuesAddress",
    "SeasonVenuesModelSite",
    "SeasonVenuesModelSiteResourceType",
    "SeasonVenuesModelSocialMedia",
    "SebsListCompetitorType",
    "SebsListFixtureType",
    "SebsListRepresentingCountry",
    "SebsListResponseDefault",
    "SebsListSeasonEntityBaseStatisticsResponse",
    "SepDetailResponseDefault",
    "SepDetailSeasonEntityPlacingsResponse",
    "SepListResponseDefault",
    "SepListSeasonEntityPlacingsResponse",
    "SeriesModel",
    "SeriesModelConference",
    "SeriesModelConferenceResourceType",
    "SeriesModelDivision",
    "SeriesModelDivisionResourceType",
    "SeriesModelOrganization",
    "SeriesModelOrganizationResourceType",
    "SeriesModelPool",
    "SeriesModelPoolResourceType",
    "SeriesModelSeason",
    "SeriesModelSeasonResourceType",
    "SeriesModelSeasonSeriesCompetitor",
    "SeriesModelSeasonSeriesCompetitorSeriesResult",
    "SeriesModelSeriesType",
    "SeriesModelStage",
    "SeriesModelStageResourceType",
    "SeriesModelStatus",
    "SesListFixtureType",
    "SesListHomeAway",
    "SesListperiodsFixtureType",
    "SesListperiodsHomeAway",
    "SesListperiodsPeriodId",
    "SesListperiodsResponseDefault",
    "SesListperiodsSeasonEntityStatisticsResponse",
    "SesListperiodsWinLoss",
    "SesListResponseDefault",
    "SesListSeasonEntityStatisticsResponse",
    "SesListWinLoss",
    "SiteDetailResponseDefault",
    "SiteDetailSitesResponse",
    "SiteExternalIdsDetailResponseDefault",
    "SiteExternalIdsDetailSiteExternalIdsResponse",
    "SiteExternalIdsListResponseDefault",
    "SiteExternalIdsListSiteExternalIdsResponse",
    "SiteExternalIdsModel",
    "SiteExternalIdsModelOrganization",
    "SiteExternalIdsModelOrganizationResourceType",
    "SiteExternalIdsModelSite",
    "SiteExternalIdsModelSiteResourceType",
    "SiteListResponseDefault",
    "SiteListSitesResponse",
    "SiteModel",
    "SiteModelOrganization",
    "SiteModelOrganizationResourceType",
    "SiteModelSiteAddress",
    "SiteModelSocialMedia",
    "SlListFixtureType",
    "SlListHomeAway",
    "SlListResponseDefault",
    "SlListSeasonPersonStatisticsResponse",
    "SlListSummaryFixtureType",
    "SlListSummaryHomeAway",
    "SlListSummaryLeaderSummaryResponse",
    "SlListSummaryResponseDefault",
    "SlListSummaryWinLoss",
    "SlListWinLoss",
    "SpbsListCompetitorType",
    "SpbsListFixtureType",
    "SpbsListRepresentingCountry",
    "SpbsListResponseDefault",
    "SpbsListSeasonPersonBaseStatisticsResponse",
    "SppDetailResponseDefault",
    "SppDetailSeasonPersonPlacingsResponse",
    "SppListResponseDefault",
    "SppListSeasonPersonPlacingsResponse",
    "SpsListFixtureType",
    "SpsListHomeAway",
    "SpsListResponseDefault",
    "SpsListSeasonPersonStatisticsResponse",
    "SpsListWinLoss",
    "SpspListperiodsFixtureType",
    "SpspListperiodsHomeAway",
    "SpspListperiodsPeriodId",
    "SpspListperiodsResponseDefault",
    "SpspListperiodsWinLoss",
    "SptsListFixtureType",
    "SptsListHomeAway",
    "SptsListResponseDefault",
    "SptsListSeasonPersonTotalStatisticsResponse",
    "SptsListWinLoss",
    "StandingAdjustmentModel",
    "StandingAdjustmentModelAdjustmentField",
    "StandingAdjustmentModelAdjustmentGroup",
    "StandingAdjustmentModelAdjustmentType",
    "StandingAdjustmentModelConference",
    "StandingAdjustmentModelConferenceResourceType",
    "StandingAdjustmentModelDivision",
    "StandingAdjustmentModelDivisionResourceType",
    "StandingAdjustmentModelEntity",
    "StandingAdjustmentModelEntityResourceType",
    "StandingAdjustmentModelOrganization",
    "StandingAdjustmentModelOrganizationResourceType",
    "StandingAdjustmentModelPool",
    "StandingAdjustmentModelPoolResourceType",
    "StandingAdjustmentModelRound",
    "StandingAdjustmentModelRoundResourceType",
    "StandingAdjustmentModelSeason",
    "StandingAdjustmentModelSeasonResourceType",
    "StandingAdjustmentModelStage",
    "StandingAdjustmentModelStageResourceType",
    "StandingAdjustmentsDetailResponseDefault",
    "StandingAdjustmentsDetailStandingAdjustmentsResponse",
    "StandingAdjustmentsListResponseDefault",
    "StandingAdjustmentsListStandingAdjustmentsResponse",
    "StandingConfigurationsDetailResponseDefault",
    "StandingConfigurationsDetailStandingConfigurationsResponse",
    "StandingConfigurationsListResponseDefault",
    "StandingConfigurationsListStandingConfigurationsResponse",
    "StandingConfigurationsModel",
    "StandingConfigurationsModelOrganization",
    "StandingConfigurationsModelOrganizationResourceType",
    "StandingConfigurationsModelStandingBuilding",
    "StandingConfigurationsModelStandingBuildingBuildType",
    "StandingConfigurationsModelStandingBuildingFixtureTypesItem",
    "StandingConfigurationsModelStandingBuildingGrouping",
    "StandingConfigurationsModelStandingConfiguration",
    "StandingConfigurationsModelStandingConfigurationHeadToHeadIdentification",
    "StandingConfigurationsModelStandingConfigurationHeadToHeadIdentificationForSubsequentChecks",
    "StandingConfigurationsModelStandingConfigurationHeadToHeadResolution",
    "StandingConfigurationsModelStandingConfigurationHeadToHeadResolutionForExtraDepthH2Hs",
    "StandingConfigurationsModelStandingConfigurationHeadToHeadResolutionForExtraDepthH2HsSortDirection",
    "StandingConfigurationsModelStandingConfigurationHeadToHeadResolutionSortDirection",
    "StandingConfigurationsModelStandingConfigurationSorting",
    "StandingConfigurationsModelStandingConfigurationSortingSortDirection",
    "StandingConfigurationsModelStandingConfigurationStreak",
    "StandingDetailResponseDefault",
    "StandingDetailStandingsResponse",
    "StandingListFixtureType",
    "StandingListGroupingBase",
    "StandingListGroupingConferenceDivision",
    "StandingListGroupingStagePool",
    "StandingListResponseDefault",
    "StandingListStandingsResponse",
    "StandingLiveListFixtureType",
    "StandingLiveListGroupingBase",
    "StandingLiveListGroupingConferenceDivision",
    "StandingLiveListGroupingStagePool",
    "StandingLiveListResponseDefault",
    "StandingLiveListStandingsResponse",
    "StandingModel",
    "StandingModelCalculated",
    "StandingModelCalculatedAdditionalProperty",
    "StandingModelConference",
    "StandingModelConferenceResourceType",
    "StandingModelDivision",
    "StandingModelDivisionResourceType",
    "StandingModelEntity",
    "StandingModelEntityResourceType",
    "StandingModelFixtureType",
    "StandingModelGroupingBase",
    "StandingModelGroupingConferenceDivision",
    "StandingModelGroupingStagePool",
    "StandingModelOrganization",
    "StandingModelOrganizationResourceType",
    "StandingModelPoints",
    "StandingModelPointsAdditionalProperty",
    "StandingModelPool",
    "StandingModelPoolResourceType",
    "StandingModelRound",
    "StandingModelRoundResourceType",
    "StandingModelSeason",
    "StandingModelSeasonResourceType",
    "StandingModelStage",
    "StandingModelStageResourceType",
    "StandingModelStandingConfiguration",
    "StandingModelStandingConfigurationResourceType",
    "StandingProgressionsDetailResponseDefault",
    "StandingProgressionsDetailStandingProgressionsResponse",
    "StandingProgressionsListResponseDefault",
    "StandingProgressionsListStandingProgressionsResponse",
    "StandingProgressionsModel",
    "StandingProgressionsModelOrganization",
    "StandingProgressionsModelOrganizationResourceType",
    "StandingProgressionsModelPool",
    "StandingProgressionsModelPoolResourceType",
    "StandingProgressionsModelSeason",
    "StandingProgressionsModelSeasonResourceType",
    "StandingProgressionsModelStage",
    "StandingProgressionsModelStageResourceType",
    "TeamExternalIdsModel",
    "TeamExternalIdsModelEntity",
    "TeamExternalIdsModelEntityResourceType",
    "TeamExternalIdsModelOrganization",
    "TeamExternalIdsModelOrganizationResourceType",
    "TeamModel",
    "TeamModelAdditionalNames",
    "TeamModelAgeGroupType1",
    "TeamModelAgeGroupType2Type1",
    "TeamModelAgeGroupType3Type1",
    "TeamModelColors",
    "TeamModelContactDetails",
    "TeamModelDisciplineType1",
    "TeamModelDisciplineType2Type1",
    "TeamModelDisciplineType3Type1",
    "TeamModelEntityAdditionalDetails",
    "TeamModelEntityGroup",
    "TeamModelEntityGroupResourceType",
    "TeamModelGenderType1",
    "TeamModelGenderType2Type1",
    "TeamModelGenderType3Type1",
    "TeamModelOrganization",
    "TeamModelOrganizationResourceType",
    "TeamModelSocialMedia",
    "TeamModelStandardType1",
    "TeamModelStandardType2Type1",
    "TeamModelStandardType3Type1",
    "TeamModelStatus",
    "TeamModelTeamAddress",
    "TeamModelTeamHistoricalName",
    "TransferDetailResponseDefault",
    "TransferDetailTransfersResponse",
    "TransferModel",
    "TransferModelCompetition",
    "TransferModelCompetitionResourceType",
    "TransferModelOrganization",
    "TransferModelOrganizationResourceType",
    "TransferModelSeason",
    "TransferModelSeasonResourceType",
    "TransferModelStatusType1",
    "TransferModelStatusType2Type1",
    "TransferModelStatusType3Type1",
    "TransferModelTransferComponent",
    "TransferModelTransferType",
    "TransfersListResponseDefault",
    "TransfersListTransfersResponse",
    "TransfersListTransferType",
    "UniformItemsBySeasonListItemType",
    "UniformItemsBySeasonListResponseDefault",
    "UniformItemsBySeasonListUniformItemsResponse",
    "UniformItemsDetailResponseDefault",
    "UniformItemsDetailUniformItemsResponse",
    "UniformItemsListItemType",
    "UniformItemsListResponseDefault",
    "UniformItemsListUniformItemsResponse",
    "UniformItemsModel",
    "UniformItemsModelColors",
    "UniformItemsModelItemType",
    "UniformItemsModelOrganization",
    "UniformItemsModelOrganizationResourceType",
    "UniformItemsModelUniform",
    "UniformItemsModelUniformResourceType",
    "UniformsBySeasonListBaseType",
    "UniformsBySeasonListResponseDefault",
    "UniformsBySeasonListUniformsResponse",
    "UniformsDetailResponseDefault",
    "UniformsDetailUniformsResponse",
    "UniformsListBaseType",
    "UniformsListResponseDefault",
    "UniformsListUniformsResponse",
    "UniformsModel",
    "UniformsModelBaseType",
    "UniformsModelOrganization",
    "UniformsModelOrganizationResourceType",
    "VenueDetailResponseDefault",
    "VenueDetailVenuesResponse",
    "VenueExternalIdsDetailResponseDefault",
    "VenueExternalIdsDetailVenueExternalIdsResponse",
    "VenueExternalIdsListResponseDefault",
    "VenueExternalIdsListVenueExternalIdsResponse",
    "VenueExternalIdsModel",
    "VenueExternalIdsModelOrganization",
    "VenueExternalIdsModelOrganizationResourceType",
    "VenueExternalIdsModelVenue",
    "VenueExternalIdsModelVenueResourceType",
    "VenueListBySiteIdResponseDefault",
    "VenueListBySiteIdStatus",
    "VenueListBySiteIdVenuesResponse",
    "VenueListResponseDefault",
    "VenueListStatus",
    "VenueListVenuesResponse",
    "VenueModel",
    "VenueModelOrganization",
    "VenueModelOrganizationResourceType",
    "VenueModelSite",
    "VenueModelSiteResourceType",
    "VenueModelSocialMedia",
    "VenueModelStatus",
    "VenueModelVenueAddress",
    "VenueModelVenueHistoricalName",
    "VideoFileDetailResponseDefault",
    "VideoFileListContent",
    "VideoFileListFeedType",
    "VideoFileListFormat",
    "VideoFileListOrigin",
    "VideoFileListResponseDefault",
    "VideoFileListStatus",
    "VideoFileListStorageProvider",
    "VideoFileListVideoFilesResponse",
    "VideoFileModel",
    "VideoFileModelContent",
    "VideoFileModelFeedType",
    "VideoFileModelFixture",
    "VideoFileModelFixtureResourceType",
    "VideoFileModelFormat",
    "VideoFileModelOrganization",
    "VideoFileModelOrganizationResourceType",
    "VideoFileModelOriginType1",
    "VideoFileModelOriginType2Type1",
    "VideoFileModelOriginType3Type1",
    "VideoFileModelResolution",
    "VideoFileModelStatusType1",
    "VideoFileModelStatusType2Type1",
    "VideoFileModelStatusType3Type1",
    "VideoFileModelStorageProviderType1",
    "VideoFileModelStorageProviderType2Type1",
    "VideoFileModelStorageProviderType3Type1",
    "VideoStreamInputsFixtureListFeedType",
    "VideoStreamInputsFixtureListResponseDefault",
    "VideoStreamInputsFixtureListVideoStreamInputsResponse",
    "VideoStreamInputsListFeedType",
    "VideoStreamInputsListResponseDefault",
    "VideoStreamInputsListVideoStreamInputsResponse",
    "VideoStreamInputsModel",
    "VideoStreamInputsModelAudioAmbienceChannel",
    "VideoStreamInputsModelAudioCommentaryChannel",
    "VideoStreamInputsModelCompetition",
    "VideoStreamInputsModelCompetitionResourceType",
    "VideoStreamInputsModelFeedType",
    "VideoStreamInputsModelFixture",
    "VideoStreamInputsModelFixtureResourceType",
    "VideoStreamInputsModelInputResolution",
    "VideoStreamInputsModelOrganization",
    "VideoStreamInputsModelOrganizationResourceType",
    "VideoStreamInputsModelVenue",
    "VideoStreamInputsModelVenueResourceType",
    "VideoStreamInputsOrgListFeedType",
    "VideoStreamInputsOrgListResponseDefault",
    "VideoStreamInputsOrgListVideoStreamInputsResponse",
    "VideoStreamLocalDetailResponseDefault",
    "VideoStreamLocalDetailVideoStreamLocalResponse",
    "VideoStreamLocalListFormat",
    "VideoStreamLocalListResponseDefault",
    "VideoStreamLocalListVideoStreamLocalResponse",
    "VideoStreamLocalModel",
    "VideoStreamLocalModelFixture",
    "VideoStreamLocalModelFixtureResourceType",
    "VideoStreamLocalModelFormat",
    "VideoStreamLocalModelOrganization",
    "VideoStreamLocalModelOrganizationResourceType",
    "VideoStreamOutputsFixtureListContent",
    "VideoStreamOutputsFixtureListFeedType",
    "VideoStreamOutputsFixtureListResponseDefault",
    "VideoStreamOutputsFixtureListVideoStreamOutputsResponse",
    "VideoStreamOutputsModel",
    "VideoStreamOutputsModelCompetition",
    "VideoStreamOutputsModelCompetitionResourceType",
    "VideoStreamOutputsModelContent",
    "VideoStreamOutputsModelFeedType",
    "VideoStreamOutputsModelFixture",
    "VideoStreamOutputsModelFixtureResourceType",
    "VideoStreamOutputsModelInputResolution",
    "VideoStreamOutputsModelOrganization",
    "VideoStreamOutputsModelOrganizationResourceType",
    "VideoStreamOutputsModelVenue",
    "VideoStreamOutputsModelVenueResourceType",
    "VideoStreamOutputsOrggroupListContent",
    "VideoStreamOutputsOrggroupListFeedType",
    "VideoStreamOutputsOrggroupListResponseDefault",
    "VideoStreamOutputsOrggroupListVideoStreamOutputsResponse",
    "VideoStreamOutputsOrgListContent",
    "VideoStreamOutputsOrgListFeedType",
    "VideoStreamOutputsOrgListResponseDefault",
    "VideoStreamOutputsOrgListVideoStreamOutputsResponse",
    "VideoSubscriptionDetailResponseDefault",
    "VideoSubscriptionDetailVideoSubscriptionsResponse",
    "VideoSubscriptionListResponseDefault",
    "VideoSubscriptionListVideoSubscriptionsResponse",
    "VideoSubscriptionModel",
    "VideoSubscriptionModelAudio",
    "VideoSubscriptionModelContent",
    "VideoSubscriptionModelFeedType",
    "VideoSubscriptionModelFixture",
    "VideoSubscriptionModelFixtureResourceType",
    "VideoSubscriptionModelOrganization",
    "VideoSubscriptionModelOrganizationResourceType",
    "VideoSubscriptionModelOutputFormat",
    "VideoSubscriptionModelOutputResolution",
)
